/* Automatically generated by tree-sitter v0.25.3 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 396
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 142
#define ALIAS_COUNT 0
#define TOKEN_COUNT 62
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 0
#define MAX_ALIAS_SEQUENCE_LENGTH 8
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 1
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_schema = 1,
  anon_sym_LBRACE = 2,
  anon_sym_RBRACE = 3,
  anon_sym_extend = 4,
  anon_sym_scalar = 5,
  anon_sym_type = 6,
  anon_sym_interface = 7,
  anon_sym_union = 8,
  anon_sym_enum = 9,
  anon_sym_input = 10,
  anon_sym_AMP = 11,
  anon_sym_implements = 12,
  anon_sym_COLON = 13,
  anon_sym_LPAREN = 14,
  anon_sym_RPAREN = 15,
  anon_sym_EQ = 16,
  anon_sym_PIPE = 17,
  anon_sym_query = 18,
  anon_sym_mutation = 19,
  anon_sym_subscription = 20,
  anon_sym_DOLLAR = 21,
  anon_sym_DQUOTE_DQUOTE_DQUOTE = 22,
  aux_sym_string_value_token1 = 23,
  anon_sym_DQUOTE = 24,
  aux_sym_string_value_token2 = 25,
  sym_int_value = 26,
  sym_float_value = 27,
  anon_sym_true = 28,
  anon_sym_false = 29,
  sym_null_value = 30,
  anon_sym_LBRACK = 31,
  anon_sym_RBRACK = 32,
  anon_sym_DOT_DOT_DOT = 33,
  anon_sym_fragment = 34,
  anon_sym_on = 35,
  anon_sym_AT = 36,
  anon_sym_directive = 37,
  anon_sym_repeatable = 38,
  anon_sym_QUERY = 39,
  anon_sym_MUTATION = 40,
  anon_sym_SUBSCRIPTION = 41,
  anon_sym_FIELD = 42,
  anon_sym_FRAGMENT_DEFINITION = 43,
  anon_sym_FRAGMENT_SPREAD = 44,
  anon_sym_INLINE_FRAGMENT = 45,
  anon_sym_VARIABLE_DEFINITION = 46,
  anon_sym_SCHEMA = 47,
  anon_sym_SCALAR = 48,
  anon_sym_OBJECT = 49,
  anon_sym_FIELD_DEFINITION = 50,
  anon_sym_ARGUMENT_DEFINITION = 51,
  anon_sym_INTERFACE = 52,
  anon_sym_UNION = 53,
  anon_sym_ENUM = 54,
  anon_sym_ENUM_VALUE = 55,
  anon_sym_INPUT_OBJECT = 56,
  anon_sym_INPUT_FIELD_DEFINITION = 57,
  anon_sym_BANG = 58,
  sym_name = 59,
  sym_comment = 60,
  sym_comma = 61,
  sym_source_file = 62,
  sym_document = 63,
  sym_definition = 64,
  sym_executable_definition = 65,
  sym_type_system_definition = 66,
  sym_type_system_extension = 67,
  sym_schema_definition = 68,
  sym_schema_extension = 69,
  sym_type_extension = 70,
  sym_scalar_type_extension = 71,
  sym_object_type_extension = 72,
  sym_interface_type_extension = 73,
  sym_union_type_extension = 74,
  sym_enum_type_extension = 75,
  sym_input_object_type_extension = 76,
  sym_input_fields_definition = 77,
  sym_enum_values_definition = 78,
  sym_enum_value_definition = 79,
  sym_implements_interfaces = 80,
  sym_fields_definition = 81,
  sym_field_definition = 82,
  sym_arguments_definition = 83,
  sym_input_value_definition = 84,
  sym_default_value = 85,
  sym_union_member_types = 86,
  sym_root_operation_type_definition = 87,
  sym_operation_definition = 88,
  sym_operation_type = 89,
  sym_type_definition = 90,
  sym_scalar_type_definition = 91,
  sym_object_type_definition = 92,
  sym_interface_type_definition = 93,
  sym_union_type_definition = 94,
  sym_enum_type_definition = 95,
  sym_input_object_type_definition = 96,
  sym_variable_definitions = 97,
  sym_variable_definition = 98,
  sym_selection_set = 99,
  sym_selection = 100,
  sym_field = 101,
  sym_alias = 102,
  sym_arguments = 103,
  sym_argument = 104,
  sym_value = 105,
  sym_variable = 106,
  sym_string_value = 107,
  sym_boolean_value = 108,
  sym_enum_value = 109,
  sym_list_value = 110,
  sym_object_value = 111,
  sym_object_field = 112,
  sym_fragment_spread = 113,
  sym_fragment_definition = 114,
  sym_fragment_name = 115,
  sym_inline_fragment = 116,
  sym_type_condition = 117,
  sym_directives = 118,
  sym_directive = 119,
  sym_directive_definition = 120,
  sym_directive_locations = 121,
  sym_directive_location = 122,
  sym_executable_directive_location = 123,
  sym_type_system_directive_location = 124,
  sym_type = 125,
  sym_named_type = 126,
  sym_list_type = 127,
  sym_non_null_type = 128,
  sym_description = 129,
  aux_sym_document_repeat1 = 130,
  aux_sym_schema_definition_repeat1 = 131,
  aux_sym_input_object_type_extension_repeat1 = 132,
  aux_sym_input_fields_definition_repeat1 = 133,
  aux_sym_enum_values_definition_repeat1 = 134,
  aux_sym_fields_definition_repeat1 = 135,
  aux_sym_variable_definitions_repeat1 = 136,
  aux_sym_selection_set_repeat1 = 137,
  aux_sym_arguments_repeat1 = 138,
  aux_sym_list_value_repeat1 = 139,
  aux_sym_object_value_repeat1 = 140,
  aux_sym_directives_repeat1 = 141,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_schema] = "schema",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_extend] = "extend",
  [anon_sym_scalar] = "scalar",
  [anon_sym_type] = "type",
  [anon_sym_interface] = "interface",
  [anon_sym_union] = "union",
  [anon_sym_enum] = "enum",
  [anon_sym_input] = "input",
  [anon_sym_AMP] = "&",
  [anon_sym_implements] = "implements",
  [anon_sym_COLON] = ":",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_EQ] = "=",
  [anon_sym_PIPE] = "|",
  [anon_sym_query] = "query",
  [anon_sym_mutation] = "mutation",
  [anon_sym_subscription] = "subscription",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = "\"\"\"",
  [aux_sym_string_value_token1] = "string_value_token1",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_value_token2] = "string_value_token2",
  [sym_int_value] = "int_value",
  [sym_float_value] = "float_value",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [sym_null_value] = "null_value",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_fragment] = "fragment",
  [anon_sym_on] = "on",
  [anon_sym_AT] = "@",
  [anon_sym_directive] = "directive",
  [anon_sym_repeatable] = "repeatable",
  [anon_sym_QUERY] = "QUERY",
  [anon_sym_MUTATION] = "MUTATION",
  [anon_sym_SUBSCRIPTION] = "SUBSCRIPTION",
  [anon_sym_FIELD] = "FIELD",
  [anon_sym_FRAGMENT_DEFINITION] = "FRAGMENT_DEFINITION",
  [anon_sym_FRAGMENT_SPREAD] = "FRAGMENT_SPREAD",
  [anon_sym_INLINE_FRAGMENT] = "INLINE_FRAGMENT",
  [anon_sym_VARIABLE_DEFINITION] = "VARIABLE_DEFINITION",
  [anon_sym_SCHEMA] = "SCHEMA",
  [anon_sym_SCALAR] = "SCALAR",
  [anon_sym_OBJECT] = "OBJECT",
  [anon_sym_FIELD_DEFINITION] = "FIELD_DEFINITION",
  [anon_sym_ARGUMENT_DEFINITION] = "ARGUMENT_DEFINITION",
  [anon_sym_INTERFACE] = "INTERFACE",
  [anon_sym_UNION] = "UNION",
  [anon_sym_ENUM] = "ENUM",
  [anon_sym_ENUM_VALUE] = "ENUM_VALUE",
  [anon_sym_INPUT_OBJECT] = "INPUT_OBJECT",
  [anon_sym_INPUT_FIELD_DEFINITION] = "INPUT_FIELD_DEFINITION",
  [anon_sym_BANG] = "!",
  [sym_name] = "name",
  [sym_comment] = "comment",
  [sym_comma] = "comma",
  [sym_source_file] = "source_file",
  [sym_document] = "document",
  [sym_definition] = "definition",
  [sym_executable_definition] = "executable_definition",
  [sym_type_system_definition] = "type_system_definition",
  [sym_type_system_extension] = "type_system_extension",
  [sym_schema_definition] = "schema_definition",
  [sym_schema_extension] = "schema_extension",
  [sym_type_extension] = "type_extension",
  [sym_scalar_type_extension] = "scalar_type_extension",
  [sym_object_type_extension] = "object_type_extension",
  [sym_interface_type_extension] = "interface_type_extension",
  [sym_union_type_extension] = "union_type_extension",
  [sym_enum_type_extension] = "enum_type_extension",
  [sym_input_object_type_extension] = "input_object_type_extension",
  [sym_input_fields_definition] = "input_fields_definition",
  [sym_enum_values_definition] = "enum_values_definition",
  [sym_enum_value_definition] = "enum_value_definition",
  [sym_implements_interfaces] = "implements_interfaces",
  [sym_fields_definition] = "fields_definition",
  [sym_field_definition] = "field_definition",
  [sym_arguments_definition] = "arguments_definition",
  [sym_input_value_definition] = "input_value_definition",
  [sym_default_value] = "default_value",
  [sym_union_member_types] = "union_member_types",
  [sym_root_operation_type_definition] = "root_operation_type_definition",
  [sym_operation_definition] = "operation_definition",
  [sym_operation_type] = "operation_type",
  [sym_type_definition] = "type_definition",
  [sym_scalar_type_definition] = "scalar_type_definition",
  [sym_object_type_definition] = "object_type_definition",
  [sym_interface_type_definition] = "interface_type_definition",
  [sym_union_type_definition] = "union_type_definition",
  [sym_enum_type_definition] = "enum_type_definition",
  [sym_input_object_type_definition] = "input_object_type_definition",
  [sym_variable_definitions] = "variable_definitions",
  [sym_variable_definition] = "variable_definition",
  [sym_selection_set] = "selection_set",
  [sym_selection] = "selection",
  [sym_field] = "field",
  [sym_alias] = "alias",
  [sym_arguments] = "arguments",
  [sym_argument] = "argument",
  [sym_value] = "value",
  [sym_variable] = "variable",
  [sym_string_value] = "string_value",
  [sym_boolean_value] = "boolean_value",
  [sym_enum_value] = "enum_value",
  [sym_list_value] = "list_value",
  [sym_object_value] = "object_value",
  [sym_object_field] = "object_field",
  [sym_fragment_spread] = "fragment_spread",
  [sym_fragment_definition] = "fragment_definition",
  [sym_fragment_name] = "fragment_name",
  [sym_inline_fragment] = "inline_fragment",
  [sym_type_condition] = "type_condition",
  [sym_directives] = "directives",
  [sym_directive] = "directive",
  [sym_directive_definition] = "directive_definition",
  [sym_directive_locations] = "directive_locations",
  [sym_directive_location] = "directive_location",
  [sym_executable_directive_location] = "executable_directive_location",
  [sym_type_system_directive_location] = "type_system_directive_location",
  [sym_type] = "type",
  [sym_named_type] = "named_type",
  [sym_list_type] = "list_type",
  [sym_non_null_type] = "non_null_type",
  [sym_description] = "description",
  [aux_sym_document_repeat1] = "document_repeat1",
  [aux_sym_schema_definition_repeat1] = "schema_definition_repeat1",
  [aux_sym_input_object_type_extension_repeat1] = "input_object_type_extension_repeat1",
  [aux_sym_input_fields_definition_repeat1] = "input_fields_definition_repeat1",
  [aux_sym_enum_values_definition_repeat1] = "enum_values_definition_repeat1",
  [aux_sym_fields_definition_repeat1] = "fields_definition_repeat1",
  [aux_sym_variable_definitions_repeat1] = "variable_definitions_repeat1",
  [aux_sym_selection_set_repeat1] = "selection_set_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_list_value_repeat1] = "list_value_repeat1",
  [aux_sym_object_value_repeat1] = "object_value_repeat1",
  [aux_sym_directives_repeat1] = "directives_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_schema] = anon_sym_schema,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_extend] = anon_sym_extend,
  [anon_sym_scalar] = anon_sym_scalar,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_input] = anon_sym_input,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_implements] = anon_sym_implements,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_query] = anon_sym_query,
  [anon_sym_mutation] = anon_sym_mutation,
  [anon_sym_subscription] = anon_sym_subscription,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [aux_sym_string_value_token1] = aux_sym_string_value_token1,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_value_token2] = aux_sym_string_value_token2,
  [sym_int_value] = sym_int_value,
  [sym_float_value] = sym_float_value,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [sym_null_value] = sym_null_value,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_fragment] = anon_sym_fragment,
  [anon_sym_on] = anon_sym_on,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_directive] = anon_sym_directive,
  [anon_sym_repeatable] = anon_sym_repeatable,
  [anon_sym_QUERY] = anon_sym_QUERY,
  [anon_sym_MUTATION] = anon_sym_MUTATION,
  [anon_sym_SUBSCRIPTION] = anon_sym_SUBSCRIPTION,
  [anon_sym_FIELD] = anon_sym_FIELD,
  [anon_sym_FRAGMENT_DEFINITION] = anon_sym_FRAGMENT_DEFINITION,
  [anon_sym_FRAGMENT_SPREAD] = anon_sym_FRAGMENT_SPREAD,
  [anon_sym_INLINE_FRAGMENT] = anon_sym_INLINE_FRAGMENT,
  [anon_sym_VARIABLE_DEFINITION] = anon_sym_VARIABLE_DEFINITION,
  [anon_sym_SCHEMA] = anon_sym_SCHEMA,
  [anon_sym_SCALAR] = anon_sym_SCALAR,
  [anon_sym_OBJECT] = anon_sym_OBJECT,
  [anon_sym_FIELD_DEFINITION] = anon_sym_FIELD_DEFINITION,
  [anon_sym_ARGUMENT_DEFINITION] = anon_sym_ARGUMENT_DEFINITION,
  [anon_sym_INTERFACE] = anon_sym_INTERFACE,
  [anon_sym_UNION] = anon_sym_UNION,
  [anon_sym_ENUM] = anon_sym_ENUM,
  [anon_sym_ENUM_VALUE] = anon_sym_ENUM_VALUE,
  [anon_sym_INPUT_OBJECT] = anon_sym_INPUT_OBJECT,
  [anon_sym_INPUT_FIELD_DEFINITION] = anon_sym_INPUT_FIELD_DEFINITION,
  [anon_sym_BANG] = anon_sym_BANG,
  [sym_name] = sym_name,
  [sym_comment] = sym_comment,
  [sym_comma] = sym_comma,
  [sym_source_file] = sym_source_file,
  [sym_document] = sym_document,
  [sym_definition] = sym_definition,
  [sym_executable_definition] = sym_executable_definition,
  [sym_type_system_definition] = sym_type_system_definition,
  [sym_type_system_extension] = sym_type_system_extension,
  [sym_schema_definition] = sym_schema_definition,
  [sym_schema_extension] = sym_schema_extension,
  [sym_type_extension] = sym_type_extension,
  [sym_scalar_type_extension] = sym_scalar_type_extension,
  [sym_object_type_extension] = sym_object_type_extension,
  [sym_interface_type_extension] = sym_interface_type_extension,
  [sym_union_type_extension] = sym_union_type_extension,
  [sym_enum_type_extension] = sym_enum_type_extension,
  [sym_input_object_type_extension] = sym_input_object_type_extension,
  [sym_input_fields_definition] = sym_input_fields_definition,
  [sym_enum_values_definition] = sym_enum_values_definition,
  [sym_enum_value_definition] = sym_enum_value_definition,
  [sym_implements_interfaces] = sym_implements_interfaces,
  [sym_fields_definition] = sym_fields_definition,
  [sym_field_definition] = sym_field_definition,
  [sym_arguments_definition] = sym_arguments_definition,
  [sym_input_value_definition] = sym_input_value_definition,
  [sym_default_value] = sym_default_value,
  [sym_union_member_types] = sym_union_member_types,
  [sym_root_operation_type_definition] = sym_root_operation_type_definition,
  [sym_operation_definition] = sym_operation_definition,
  [sym_operation_type] = sym_operation_type,
  [sym_type_definition] = sym_type_definition,
  [sym_scalar_type_definition] = sym_scalar_type_definition,
  [sym_object_type_definition] = sym_object_type_definition,
  [sym_interface_type_definition] = sym_interface_type_definition,
  [sym_union_type_definition] = sym_union_type_definition,
  [sym_enum_type_definition] = sym_enum_type_definition,
  [sym_input_object_type_definition] = sym_input_object_type_definition,
  [sym_variable_definitions] = sym_variable_definitions,
  [sym_variable_definition] = sym_variable_definition,
  [sym_selection_set] = sym_selection_set,
  [sym_selection] = sym_selection,
  [sym_field] = sym_field,
  [sym_alias] = sym_alias,
  [sym_arguments] = sym_arguments,
  [sym_argument] = sym_argument,
  [sym_value] = sym_value,
  [sym_variable] = sym_variable,
  [sym_string_value] = sym_string_value,
  [sym_boolean_value] = sym_boolean_value,
  [sym_enum_value] = sym_enum_value,
  [sym_list_value] = sym_list_value,
  [sym_object_value] = sym_object_value,
  [sym_object_field] = sym_object_field,
  [sym_fragment_spread] = sym_fragment_spread,
  [sym_fragment_definition] = sym_fragment_definition,
  [sym_fragment_name] = sym_fragment_name,
  [sym_inline_fragment] = sym_inline_fragment,
  [sym_type_condition] = sym_type_condition,
  [sym_directives] = sym_directives,
  [sym_directive] = sym_directive,
  [sym_directive_definition] = sym_directive_definition,
  [sym_directive_locations] = sym_directive_locations,
  [sym_directive_location] = sym_directive_location,
  [sym_executable_directive_location] = sym_executable_directive_location,
  [sym_type_system_directive_location] = sym_type_system_directive_location,
  [sym_type] = sym_type,
  [sym_named_type] = sym_named_type,
  [sym_list_type] = sym_list_type,
  [sym_non_null_type] = sym_non_null_type,
  [sym_description] = sym_description,
  [aux_sym_document_repeat1] = aux_sym_document_repeat1,
  [aux_sym_schema_definition_repeat1] = aux_sym_schema_definition_repeat1,
  [aux_sym_input_object_type_extension_repeat1] = aux_sym_input_object_type_extension_repeat1,
  [aux_sym_input_fields_definition_repeat1] = aux_sym_input_fields_definition_repeat1,
  [aux_sym_enum_values_definition_repeat1] = aux_sym_enum_values_definition_repeat1,
  [aux_sym_fields_definition_repeat1] = aux_sym_fields_definition_repeat1,
  [aux_sym_variable_definitions_repeat1] = aux_sym_variable_definitions_repeat1,
  [aux_sym_selection_set_repeat1] = aux_sym_selection_set_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_list_value_repeat1] = aux_sym_list_value_repeat1,
  [aux_sym_object_value_repeat1] = aux_sym_object_value_repeat1,
  [aux_sym_directives_repeat1] = aux_sym_directives_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_schema] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_scalar] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_input] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implements] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_query] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mutation] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_subscription] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_value_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_value_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_int_value] = {
    .visible = true,
    .named = true,
  },
  [sym_float_value] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [sym_null_value] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fragment] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_on] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_directive] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_repeatable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QUERY] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_MUTATION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SUBSCRIPTION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FIELD] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FRAGMENT_DEFINITION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FRAGMENT_SPREAD] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_INLINE_FRAGMENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_VARIABLE_DEFINITION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SCHEMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SCALAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_OBJECT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FIELD_DEFINITION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ARGUMENT_DEFINITION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_INTERFACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_UNION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENUM] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENUM_VALUE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_INPUT_OBJECT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_INPUT_FIELD_DEFINITION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [sym_name] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_document] = {
    .visible = true,
    .named = true,
  },
  [sym_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_executable_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_type_system_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_type_system_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_schema_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_schema_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_type_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_scalar_type_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_object_type_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_type_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_union_type_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_type_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_input_object_type_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_input_fields_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_values_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_value_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_implements_interfaces] = {
    .visible = true,
    .named = true,
  },
  [sym_fields_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_field_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_input_value_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_default_value] = {
    .visible = true,
    .named = true,
  },
  [sym_union_member_types] = {
    .visible = true,
    .named = true,
  },
  [sym_root_operation_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_operation_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_operation_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_scalar_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_object_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_union_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_input_object_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_definitions] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_selection_set] = {
    .visible = true,
    .named = true,
  },
  [sym_selection] = {
    .visible = true,
    .named = true,
  },
  [sym_field] = {
    .visible = true,
    .named = true,
  },
  [sym_alias] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_value] = {
    .visible = true,
    .named = true,
  },
  [sym_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_string_value] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_value] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_value] = {
    .visible = true,
    .named = true,
  },
  [sym_list_value] = {
    .visible = true,
    .named = true,
  },
  [sym_object_value] = {
    .visible = true,
    .named = true,
  },
  [sym_object_field] = {
    .visible = true,
    .named = true,
  },
  [sym_fragment_spread] = {
    .visible = true,
    .named = true,
  },
  [sym_fragment_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_fragment_name] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym_type_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_directives] = {
    .visible = true,
    .named = true,
  },
  [sym_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_directive_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_directive_locations] = {
    .visible = true,
    .named = true,
  },
  [sym_directive_location] = {
    .visible = true,
    .named = true,
  },
  [sym_executable_directive_location] = {
    .visible = true,
    .named = true,
  },
  [sym_type_system_directive_location] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym_named_type] = {
    .visible = true,
    .named = true,
  },
  [sym_list_type] = {
    .visible = true,
    .named = true,
  },
  [sym_non_null_type] = {
    .visible = true,
    .named = true,
  },
  [sym_description] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_document_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_schema_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_input_object_type_extension_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_input_fields_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_values_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fields_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_definitions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_selection_set_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_directives_repeat1] = {
    .visible = false,
    .named = false,
  },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 37,
  [39] = 39,
  [40] = 40,
  [41] = 39,
  [42] = 37,
  [43] = 39,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 78,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 34,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 36,
  [159] = 159,
  [160] = 153,
  [161] = 161,
  [162] = 35,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 54,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 45,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 20,
  [185] = 185,
  [186] = 177,
  [187] = 146,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 145,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 139,
  [205] = 142,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 143,
  [212] = 144,
  [213] = 213,
  [214] = 146,
  [215] = 215,
  [216] = 216,
  [217] = 210,
  [218] = 218,
  [219] = 140,
  [220] = 220,
  [221] = 141,
  [222] = 222,
  [223] = 138,
  [224] = 224,
  [225] = 141,
  [226] = 146,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 157,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 35,
  [238] = 34,
  [239] = 36,
  [240] = 20,
  [241] = 145,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 155,
  [248] = 138,
  [249] = 140,
  [250] = 139,
  [251] = 142,
  [252] = 143,
  [253] = 144,
  [254] = 181,
  [255] = 255,
  [256] = 256,
  [257] = 35,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 36,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 182,
  [271] = 271,
  [272] = 272,
  [273] = 262,
  [274] = 268,
  [275] = 271,
  [276] = 262,
  [277] = 268,
  [278] = 271,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 125,
  [284] = 284,
  [285] = 45,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 54,
  [294] = 290,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 218,
  [300] = 290,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 265,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 350,
  [362] = 362,
  [363] = 363,
  [364] = 327,
  [365] = 326,
  [366] = 366,
  [367] = 333,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 371,
  [373] = 373,
  [374] = 350,
  [375] = 327,
  [376] = 326,
  [377] = 333,
  [378] = 378,
  [379] = 170,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 327,
  [384] = 326,
  [385] = 385,
  [386] = 338,
  [387] = 345,
  [388] = 388,
  [389] = 389,
  [390] = 338,
  [391] = 345,
  [392] = 392,
  [393] = 338,
  [394] = 345,
  [395] = 395,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(269);
      ADVANCE_MAP(
        '!', 338,
        '"', 296,
        '#', 353,
        '$', 290,
        '&', 280,
        '(', 283,
        ')', 284,
        ',', 354,
        '-', 8,
        '.', 7,
        '0', 300,
        ':', 282,
        '=', 285,
        '@', 316,
        'A', 134,
        'E', 114,
        'F', 68,
        'I', 104,
        'M', 157,
        'O', 20,
        'Q', 159,
        'S', 24,
        'U', 105,
        'V', 10,
        '[', 310,
        ']', 311,
        'd', 205,
        'e', 228,
        'f', 171,
        'i', 217,
        'm', 259,
        'n', 260,
        'o', 222,
        'q', 258,
        'r', 195,
        's', 182,
        't', 244,
        'u', 227,
        '{', 271,
        '|', 286,
        '}', 272,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(0);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(301);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 338,
        '"', 296,
        '#', 353,
        '$', 290,
        '&', 280,
        '(', 283,
        ')', 284,
        ',', 354,
        '.', 7,
        ':', 282,
        '=', 285,
        '@', 316,
        '[', 310,
        ']', 311,
        '{', 271,
        '|', 286,
        '}', 272,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '"', 296,
        '#', 353,
        '$', 290,
        ',', 354,
        '-', 8,
        '0', 300,
        '[', 310,
        ']', 311,
        'f', 339,
        'n', 349,
        't', 346,
        '{', 271,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(2);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(301);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 3:
      if (lookahead == '"') ADVANCE(291);
      END_STATE();
    case 4:
      if (lookahead == '"') ADVANCE(295);
      if (lookahead == '#') ADVANCE(353);
      if (lookahead == ',') ADVANCE(354);
      if (lookahead == '@') ADVANCE(316);
      if (lookahead == 'o') ADVANCE(345);
      if (lookahead == '{') ADVANCE(271);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(4);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(268);
      if (lookahead != 0) ADVANCE(294);
      END_STATE();
    case 6:
      if (lookahead == '.') ADVANCE(312);
      END_STATE();
    case 7:
      if (lookahead == '.') ADVANCE(6);
      END_STATE();
    case 8:
      if (lookahead == '0') ADVANCE(300);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(301);
      END_STATE();
    case 9:
      if (lookahead == 'A') ADVANCE(327);
      END_STATE();
    case 10:
      if (lookahead == 'A') ADVANCE(138);
      END_STATE();
    case 11:
      if (lookahead == 'A') ADVANCE(66);
      END_STATE();
    case 12:
      if (lookahead == 'A') ADVANCE(97);
      if (lookahead == 'H') ADVANCE(43);
      END_STATE();
    case 13:
      if (lookahead == 'A') ADVANCE(22);
      END_STATE();
    case 14:
      if (lookahead == 'A') ADVANCE(150);
      END_STATE();
    case 15:
      if (lookahead == 'A') ADVANCE(27);
      END_STATE();
    case 16:
      if (lookahead == 'A') ADVANCE(98);
      END_STATE();
    case 17:
      if (lookahead == 'A') ADVANCE(30);
      END_STATE();
    case 18:
      if (lookahead == 'A') ADVANCE(137);
      END_STATE();
    case 19:
      if (lookahead == 'A') ADVANCE(67);
      END_STATE();
    case 20:
      if (lookahead == 'B') ADVANCE(91);
      END_STATE();
    case 21:
      if (lookahead == 'B') ADVANCE(142);
      END_STATE();
    case 22:
      if (lookahead == 'B') ADVANCE(96);
      END_STATE();
    case 23:
      if (lookahead == 'B') ADVANCE(92);
      END_STATE();
    case 24:
      if (lookahead == 'C') ADVANCE(12);
      if (lookahead == 'U') ADVANCE(21);
      END_STATE();
    case 25:
      if (lookahead == 'C') ADVANCE(144);
      END_STATE();
    case 26:
      if (lookahead == 'C') ADVANCE(145);
      END_STATE();
    case 27:
      if (lookahead == 'C') ADVANCE(39);
      END_STATE();
    case 28:
      if (lookahead == 'C') ADVANCE(139);
      END_STATE();
    case 29:
      if (lookahead == 'D') ADVANCE(322);
      END_STATE();
    case 30:
      if (lookahead == 'D') ADVANCE(324);
      END_STATE();
    case 31:
      if (lookahead == 'D') ADVANCE(44);
      END_STATE();
    case 32:
      if (lookahead == 'D') ADVANCE(52);
      END_STATE();
    case 33:
      if (lookahead == 'D') ADVANCE(53);
      if (lookahead == 'S') ADVANCE(132);
      END_STATE();
    case 34:
      if (lookahead == 'D') ADVANCE(54);
      END_STATE();
    case 35:
      if (lookahead == 'D') ADVANCE(55);
      END_STATE();
    case 36:
      if (lookahead == 'D') ADVANCE(170);
      END_STATE();
    case 37:
      if (lookahead == 'E') ADVANCE(93);
      END_STATE();
    case 38:
      if (lookahead == 'E') ADVANCE(25);
      END_STATE();
    case 39:
      if (lookahead == 'E') ADVANCE(332);
      END_STATE();
    case 40:
      if (lookahead == 'E') ADVANCE(335);
      END_STATE();
    case 41:
      if (lookahead == 'E') ADVANCE(167);
      END_STATE();
    case 42:
      if (lookahead == 'E') ADVANCE(135);
      END_STATE();
    case 43:
      if (lookahead == 'E') ADVANCE(100);
      END_STATE();
    case 44:
      if (lookahead == 'E') ADVANCE(60);
      END_STATE();
    case 45:
      if (lookahead == 'E') ADVANCE(136);
      END_STATE();
    case 46:
      if (lookahead == 'E') ADVANCE(115);
      END_STATE();
    case 47:
      if (lookahead == 'E') ADVANCE(117);
      END_STATE();
    case 48:
      if (lookahead == 'E') ADVANCE(17);
      END_STATE();
    case 49:
      if (lookahead == 'E') ADVANCE(119);
      END_STATE();
    case 50:
      if (lookahead == 'E') ADVANCE(95);
      END_STATE();
    case 51:
      if (lookahead == 'E') ADVANCE(26);
      END_STATE();
    case 52:
      if (lookahead == 'E') ADVANCE(61);
      END_STATE();
    case 53:
      if (lookahead == 'E') ADVANCE(62);
      END_STATE();
    case 54:
      if (lookahead == 'E') ADVANCE(63);
      END_STATE();
    case 55:
      if (lookahead == 'E') ADVANCE(64);
      END_STATE();
    case 56:
      if (lookahead == 'E') ADVANCE(169);
      END_STATE();
    case 57:
      if (lookahead == 'F') ADVANCE(81);
      if (lookahead == 'O') ADVANCE(23);
      END_STATE();
    case 58:
      if (lookahead == 'F') ADVANCE(141);
      END_STATE();
    case 59:
      if (lookahead == 'F') ADVANCE(15);
      END_STATE();
    case 60:
      if (lookahead == 'F') ADVANCE(73);
      END_STATE();
    case 61:
      if (lookahead == 'F') ADVANCE(87);
      END_STATE();
    case 62:
      if (lookahead == 'F') ADVANCE(88);
      END_STATE();
    case 63:
      if (lookahead == 'F') ADVANCE(89);
      END_STATE();
    case 64:
      if (lookahead == 'F') ADVANCE(90);
      END_STATE();
    case 65:
      if (lookahead == 'G') ADVANCE(161);
      END_STATE();
    case 66:
      if (lookahead == 'G') ADVANCE(102);
      END_STATE();
    case 67:
      if (lookahead == 'G') ADVANCE(103);
      END_STATE();
    case 68:
      if (lookahead == 'I') ADVANCE(37);
      if (lookahead == 'R') ADVANCE(11);
      END_STATE();
    case 69:
      if (lookahead == 'I') ADVANCE(124);
      END_STATE();
    case 70:
      if (lookahead == 'I') ADVANCE(133);
      END_STATE();
    case 71:
      if (lookahead == 'I') ADVANCE(116);
      END_STATE();
    case 72:
      if (lookahead == 'I') ADVANCE(13);
      END_STATE();
    case 73:
      if (lookahead == 'I') ADVANCE(118);
      END_STATE();
    case 74:
      if (lookahead == 'I') ADVANCE(125);
      END_STATE();
    case 75:
      if (lookahead == 'I') ADVANCE(126);
      END_STATE();
    case 76:
      if (lookahead == 'I') ADVANCE(127);
      END_STATE();
    case 77:
      if (lookahead == 'I') ADVANCE(128);
      END_STATE();
    case 78:
      if (lookahead == 'I') ADVANCE(129);
      END_STATE();
    case 79:
      if (lookahead == 'I') ADVANCE(130);
      END_STATE();
    case 80:
      if (lookahead == 'I') ADVANCE(131);
      END_STATE();
    case 81:
      if (lookahead == 'I') ADVANCE(50);
      END_STATE();
    case 82:
      if (lookahead == 'I') ADVANCE(152);
      END_STATE();
    case 83:
      if (lookahead == 'I') ADVANCE(153);
      END_STATE();
    case 84:
      if (lookahead == 'I') ADVANCE(154);
      END_STATE();
    case 85:
      if (lookahead == 'I') ADVANCE(155);
      END_STATE();
    case 86:
      if (lookahead == 'I') ADVANCE(156);
      END_STATE();
    case 87:
      if (lookahead == 'I') ADVANCE(120);
      END_STATE();
    case 88:
      if (lookahead == 'I') ADVANCE(121);
      END_STATE();
    case 89:
      if (lookahead == 'I') ADVANCE(122);
      END_STATE();
    case 90:
      if (lookahead == 'I') ADVANCE(123);
      END_STATE();
    case 91:
      if (lookahead == 'J') ADVANCE(38);
      END_STATE();
    case 92:
      if (lookahead == 'J') ADVANCE(51);
      END_STATE();
    case 93:
      if (lookahead == 'L') ADVANCE(29);
      END_STATE();
    case 94:
      if (lookahead == 'L') ADVANCE(71);
      if (lookahead == 'P') ADVANCE(160);
      if (lookahead == 'T') ADVANCE(45);
      END_STATE();
    case 95:
      if (lookahead == 'L') ADVANCE(36);
      END_STATE();
    case 96:
      if (lookahead == 'L') ADVANCE(56);
      END_STATE();
    case 97:
      if (lookahead == 'L') ADVANCE(18);
      END_STATE();
    case 98:
      if (lookahead == 'L') ADVANCE(162);
      END_STATE();
    case 99:
      if (lookahead == 'M') ADVANCE(334);
      END_STATE();
    case 100:
      if (lookahead == 'M') ADVANCE(9);
      END_STATE();
    case 101:
      if (lookahead == 'M') ADVANCE(46);
      END_STATE();
    case 102:
      if (lookahead == 'M') ADVANCE(47);
      END_STATE();
    case 103:
      if (lookahead == 'M') ADVANCE(49);
      END_STATE();
    case 104:
      if (lookahead == 'N') ADVANCE(94);
      END_STATE();
    case 105:
      if (lookahead == 'N') ADVANCE(69);
      END_STATE();
    case 106:
      if (lookahead == 'N') ADVANCE(333);
      END_STATE();
    case 107:
      if (lookahead == 'N') ADVANCE(320);
      END_STATE();
    case 108:
      if (lookahead == 'N') ADVANCE(321);
      END_STATE();
    case 109:
      if (lookahead == 'N') ADVANCE(330);
      END_STATE();
    case 110:
      if (lookahead == 'N') ADVANCE(331);
      END_STATE();
    case 111:
      if (lookahead == 'N') ADVANCE(323);
      END_STATE();
    case 112:
      if (lookahead == 'N') ADVANCE(326);
      END_STATE();
    case 113:
      if (lookahead == 'N') ADVANCE(337);
      END_STATE();
    case 114:
      if (lookahead == 'N') ADVANCE(158);
      END_STATE();
    case 115:
      if (lookahead == 'N') ADVANCE(148);
      END_STATE();
    case 116:
      if (lookahead == 'N') ADVANCE(41);
      END_STATE();
    case 117:
      if (lookahead == 'N') ADVANCE(149);
      END_STATE();
    case 118:
      if (lookahead == 'N') ADVANCE(82);
      END_STATE();
    case 119:
      if (lookahead == 'N') ADVANCE(146);
      END_STATE();
    case 120:
      if (lookahead == 'N') ADVANCE(83);
      END_STATE();
    case 121:
      if (lookahead == 'N') ADVANCE(84);
      END_STATE();
    case 122:
      if (lookahead == 'N') ADVANCE(85);
      END_STATE();
    case 123:
      if (lookahead == 'N') ADVANCE(86);
      END_STATE();
    case 124:
      if (lookahead == 'O') ADVANCE(106);
      END_STATE();
    case 125:
      if (lookahead == 'O') ADVANCE(107);
      END_STATE();
    case 126:
      if (lookahead == 'O') ADVANCE(108);
      END_STATE();
    case 127:
      if (lookahead == 'O') ADVANCE(109);
      END_STATE();
    case 128:
      if (lookahead == 'O') ADVANCE(110);
      END_STATE();
    case 129:
      if (lookahead == 'O') ADVANCE(111);
      END_STATE();
    case 130:
      if (lookahead == 'O') ADVANCE(112);
      END_STATE();
    case 131:
      if (lookahead == 'O') ADVANCE(113);
      END_STATE();
    case 132:
      if (lookahead == 'P') ADVANCE(140);
      END_STATE();
    case 133:
      if (lookahead == 'P') ADVANCE(151);
      END_STATE();
    case 134:
      if (lookahead == 'R') ADVANCE(65);
      END_STATE();
    case 135:
      if (lookahead == 'R') ADVANCE(164);
      END_STATE();
    case 136:
      if (lookahead == 'R') ADVANCE(59);
      END_STATE();
    case 137:
      if (lookahead == 'R') ADVANCE(328);
      END_STATE();
    case 138:
      if (lookahead == 'R') ADVANCE(72);
      END_STATE();
    case 139:
      if (lookahead == 'R') ADVANCE(70);
      END_STATE();
    case 140:
      if (lookahead == 'R') ADVANCE(48);
      END_STATE();
    case 141:
      if (lookahead == 'R') ADVANCE(19);
      END_STATE();
    case 142:
      if (lookahead == 'S') ADVANCE(28);
      END_STATE();
    case 143:
      if (lookahead == 'T') ADVANCE(165);
      END_STATE();
    case 144:
      if (lookahead == 'T') ADVANCE(329);
      END_STATE();
    case 145:
      if (lookahead == 'T') ADVANCE(336);
      END_STATE();
    case 146:
      if (lookahead == 'T') ADVANCE(325);
      END_STATE();
    case 147:
      if (lookahead == 'T') ADVANCE(14);
      END_STATE();
    case 148:
      if (lookahead == 'T') ADVANCE(168);
      END_STATE();
    case 149:
      if (lookahead == 'T') ADVANCE(166);
      END_STATE();
    case 150:
      if (lookahead == 'T') ADVANCE(74);
      END_STATE();
    case 151:
      if (lookahead == 'T') ADVANCE(75);
      END_STATE();
    case 152:
      if (lookahead == 'T') ADVANCE(76);
      END_STATE();
    case 153:
      if (lookahead == 'T') ADVANCE(77);
      END_STATE();
    case 154:
      if (lookahead == 'T') ADVANCE(78);
      END_STATE();
    case 155:
      if (lookahead == 'T') ADVANCE(79);
      END_STATE();
    case 156:
      if (lookahead == 'T') ADVANCE(80);
      END_STATE();
    case 157:
      if (lookahead == 'U') ADVANCE(147);
      END_STATE();
    case 158:
      if (lookahead == 'U') ADVANCE(99);
      END_STATE();
    case 159:
      if (lookahead == 'U') ADVANCE(42);
      END_STATE();
    case 160:
      if (lookahead == 'U') ADVANCE(143);
      END_STATE();
    case 161:
      if (lookahead == 'U') ADVANCE(101);
      END_STATE();
    case 162:
      if (lookahead == 'U') ADVANCE(40);
      END_STATE();
    case 163:
      if (lookahead == 'V') ADVANCE(16);
      END_STATE();
    case 164:
      if (lookahead == 'Y') ADVANCE(319);
      END_STATE();
    case 165:
      if (lookahead == '_') ADVANCE(57);
      END_STATE();
    case 166:
      if (lookahead == '_') ADVANCE(33);
      END_STATE();
    case 167:
      if (lookahead == '_') ADVANCE(58);
      END_STATE();
    case 168:
      if (lookahead == '_') ADVANCE(32);
      END_STATE();
    case 169:
      if (lookahead == '_') ADVANCE(34);
      END_STATE();
    case 170:
      if (lookahead == '_') ADVANCE(35);
      END_STATE();
    case 171:
      if (lookahead == 'a') ADVANCE(211);
      if (lookahead == 'r') ADVANCE(172);
      END_STATE();
    case 172:
      if (lookahead == 'a') ADVANCE(204);
      END_STATE();
    case 173:
      if (lookahead == 'a') ADVANCE(270);
      END_STATE();
    case 174:
      if (lookahead == 'a') ADVANCE(181);
      END_STATE();
    case 175:
      if (lookahead == 'a') ADVANCE(185);
      END_STATE();
    case 176:
      if (lookahead == 'a') ADVANCE(241);
      END_STATE();
    case 177:
      if (lookahead == 'a') ADVANCE(255);
      END_STATE();
    case 178:
      if (lookahead == 'a') ADVANCE(214);
      if (lookahead == 'h') ADVANCE(199);
      END_STATE();
    case 179:
      if (lookahead == 'a') ADVANCE(254);
      END_STATE();
    case 180:
      if (lookahead == 'b') ADVANCE(246);
      END_STATE();
    case 181:
      if (lookahead == 'b') ADVANCE(216);
      END_STATE();
    case 182:
      if (lookahead == 'c') ADVANCE(178);
      if (lookahead == 'u') ADVANCE(180);
      END_STATE();
    case 183:
      if (lookahead == 'c') ADVANCE(243);
      END_STATE();
    case 184:
      if (lookahead == 'c') ADVANCE(251);
      END_STATE();
    case 185:
      if (lookahead == 'c') ADVANCE(192);
      END_STATE();
    case 186:
      if (lookahead == 'd') ADVANCE(273);
      END_STATE();
    case 187:
      if (lookahead == 'e') ADVANCE(184);
      END_STATE();
    case 188:
      if (lookahead == 'e') ADVANCE(304);
      END_STATE();
    case 189:
      if (lookahead == 'e') ADVANCE(275);
      END_STATE();
    case 190:
      if (lookahead == 'e') ADVANCE(306);
      END_STATE();
    case 191:
      if (lookahead == 'e') ADVANCE(317);
      END_STATE();
    case 192:
      if (lookahead == 'e') ADVANCE(276);
      END_STATE();
    case 193:
      if (lookahead == 'e') ADVANCE(318);
      END_STATE();
    case 194:
      if (lookahead == 'e') ADVANCE(239);
      END_STATE();
    case 195:
      if (lookahead == 'e') ADVANCE(235);
      END_STATE();
    case 196:
      if (lookahead == 'e') ADVANCE(223);
      END_STATE();
    case 197:
      if (lookahead == 'e') ADVANCE(240);
      END_STATE();
    case 198:
      if (lookahead == 'e') ADVANCE(179);
      END_STATE();
    case 199:
      if (lookahead == 'e') ADVANCE(219);
      END_STATE();
    case 200:
      if (lookahead == 'e') ADVANCE(229);
      END_STATE();
    case 201:
      if (lookahead == 'e') ADVANCE(230);
      END_STATE();
    case 202:
      if (lookahead == 'e') ADVANCE(221);
      END_STATE();
    case 203:
      if (lookahead == 'f') ADVANCE(175);
      END_STATE();
    case 204:
      if (lookahead == 'g') ADVANCE(220);
      END_STATE();
    case 205:
      if (lookahead == 'i') ADVANCE(242);
      END_STATE();
    case 206:
      if (lookahead == 'i') ADVANCE(231);
      END_STATE();
    case 207:
      if (lookahead == 'i') ADVANCE(263);
      END_STATE();
    case 208:
      if (lookahead == 'i') ADVANCE(238);
      END_STATE();
    case 209:
      if (lookahead == 'i') ADVANCE(232);
      END_STATE();
    case 210:
      if (lookahead == 'i') ADVANCE(233);
      END_STATE();
    case 211:
      if (lookahead == 'l') ADVANCE(247);
      END_STATE();
    case 212:
      if (lookahead == 'l') ADVANCE(308);
      END_STATE();
    case 213:
      if (lookahead == 'l') ADVANCE(212);
      END_STATE();
    case 214:
      if (lookahead == 'l') ADVANCE(176);
      END_STATE();
    case 215:
      if (lookahead == 'l') ADVANCE(202);
      END_STATE();
    case 216:
      if (lookahead == 'l') ADVANCE(193);
      END_STATE();
    case 217:
      if (lookahead == 'm') ADVANCE(234);
      if (lookahead == 'n') ADVANCE(237);
      END_STATE();
    case 218:
      if (lookahead == 'm') ADVANCE(278);
      END_STATE();
    case 219:
      if (lookahead == 'm') ADVANCE(173);
      END_STATE();
    case 220:
      if (lookahead == 'm') ADVANCE(200);
      END_STATE();
    case 221:
      if (lookahead == 'm') ADVANCE(201);
      END_STATE();
    case 222:
      if (lookahead == 'n') ADVANCE(314);
      END_STATE();
    case 223:
      if (lookahead == 'n') ADVANCE(186);
      END_STATE();
    case 224:
      if (lookahead == 'n') ADVANCE(277);
      END_STATE();
    case 225:
      if (lookahead == 'n') ADVANCE(288);
      END_STATE();
    case 226:
      if (lookahead == 'n') ADVANCE(289);
      END_STATE();
    case 227:
      if (lookahead == 'n') ADVANCE(206);
      END_STATE();
    case 228:
      if (lookahead == 'n') ADVANCE(257);
      if (lookahead == 'x') ADVANCE(253);
      END_STATE();
    case 229:
      if (lookahead == 'n') ADVANCE(249);
      END_STATE();
    case 230:
      if (lookahead == 'n') ADVANCE(252);
      END_STATE();
    case 231:
      if (lookahead == 'o') ADVANCE(224);
      END_STATE();
    case 232:
      if (lookahead == 'o') ADVANCE(225);
      END_STATE();
    case 233:
      if (lookahead == 'o') ADVANCE(226);
      END_STATE();
    case 234:
      if (lookahead == 'p') ADVANCE(215);
      END_STATE();
    case 235:
      if (lookahead == 'p') ADVANCE(198);
      END_STATE();
    case 236:
      if (lookahead == 'p') ADVANCE(189);
      END_STATE();
    case 237:
      if (lookahead == 'p') ADVANCE(261);
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 238:
      if (lookahead == 'p') ADVANCE(256);
      END_STATE();
    case 239:
      if (lookahead == 'r') ADVANCE(264);
      END_STATE();
    case 240:
      if (lookahead == 'r') ADVANCE(203);
      END_STATE();
    case 241:
      if (lookahead == 'r') ADVANCE(274);
      END_STATE();
    case 242:
      if (lookahead == 'r') ADVANCE(187);
      END_STATE();
    case 243:
      if (lookahead == 'r') ADVANCE(208);
      END_STATE();
    case 244:
      if (lookahead == 'r') ADVANCE(262);
      if (lookahead == 'y') ADVANCE(236);
      END_STATE();
    case 245:
      if (lookahead == 's') ADVANCE(281);
      END_STATE();
    case 246:
      if (lookahead == 's') ADVANCE(183);
      END_STATE();
    case 247:
      if (lookahead == 's') ADVANCE(190);
      END_STATE();
    case 248:
      if (lookahead == 't') ADVANCE(279);
      END_STATE();
    case 249:
      if (lookahead == 't') ADVANCE(313);
      END_STATE();
    case 250:
      if (lookahead == 't') ADVANCE(177);
      END_STATE();
    case 251:
      if (lookahead == 't') ADVANCE(207);
      END_STATE();
    case 252:
      if (lookahead == 't') ADVANCE(245);
      END_STATE();
    case 253:
      if (lookahead == 't') ADVANCE(196);
      END_STATE();
    case 254:
      if (lookahead == 't') ADVANCE(174);
      END_STATE();
    case 255:
      if (lookahead == 't') ADVANCE(209);
      END_STATE();
    case 256:
      if (lookahead == 't') ADVANCE(210);
      END_STATE();
    case 257:
      if (lookahead == 'u') ADVANCE(218);
      END_STATE();
    case 258:
      if (lookahead == 'u') ADVANCE(194);
      END_STATE();
    case 259:
      if (lookahead == 'u') ADVANCE(250);
      END_STATE();
    case 260:
      if (lookahead == 'u') ADVANCE(213);
      END_STATE();
    case 261:
      if (lookahead == 'u') ADVANCE(248);
      END_STATE();
    case 262:
      if (lookahead == 'u') ADVANCE(188);
      END_STATE();
    case 263:
      if (lookahead == 'v') ADVANCE(191);
      END_STATE();
    case 264:
      if (lookahead == 'y') ADVANCE(287);
      END_STATE();
    case 265:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(267);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(303);
      END_STATE();
    case 266:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(302);
      END_STATE();
    case 267:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(303);
      END_STATE();
    case 268:
      if (lookahead != 0 &&
          lookahead != '"') ADVANCE(294);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(anon_sym_schema);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_extend);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_scalar);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_input);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(anon_sym_implements);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(anon_sym_query);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(anon_sym_mutation);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(anon_sym_subscription);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(anon_sym_DQUOTE_DQUOTE_DQUOTE);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(aux_sym_string_value_token1);
      if (lookahead == '\n') ADVANCE(294);
      if (lookahead == '"') ADVANCE(352);
      if (lookahead != 0) ADVANCE(292);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(aux_sym_string_value_token1);
      if (lookahead == '"') ADVANCE(5);
      if (lookahead == '#') ADVANCE(292);
      if (lookahead == ',') ADVANCE(355);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) ADVANCE(293);
      if (lookahead != 0) ADVANCE(294);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(aux_sym_string_value_token1);
      if (lookahead == '"') ADVANCE(5);
      if (lookahead != 0) ADVANCE(294);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '"') ADVANCE(3);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(aux_sym_string_value_token2);
      if (lookahead == '#') ADVANCE(298);
      if (lookahead == ',') ADVANCE(356);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) ADVANCE(297);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '#' &&
          lookahead != '\\') ADVANCE(299);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(aux_sym_string_value_token2);
      if (lookahead == '"' ||
          lookahead == '\\') ADVANCE(353);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(298);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(aux_sym_string_value_token2);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(299);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(sym_int_value);
      if (lookahead == '.') ADVANCE(266);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(265);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(sym_int_value);
      if (lookahead == '.') ADVANCE(266);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(265);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(301);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(sym_float_value);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(265);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(302);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(sym_float_value);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(303);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(anon_sym_true);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(anon_sym_false);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(sym_null_value);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(sym_null_value);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(anon_sym_fragment);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(anon_sym_on);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(anon_sym_on);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(anon_sym_directive);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(anon_sym_repeatable);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(anon_sym_QUERY);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(anon_sym_MUTATION);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(anon_sym_SUBSCRIPTION);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(anon_sym_FIELD);
      if (lookahead == '_') ADVANCE(31);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(anon_sym_FRAGMENT_DEFINITION);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(anon_sym_FRAGMENT_SPREAD);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(anon_sym_INLINE_FRAGMENT);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(anon_sym_VARIABLE_DEFINITION);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(anon_sym_SCHEMA);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(anon_sym_SCALAR);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(anon_sym_OBJECT);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(anon_sym_FIELD_DEFINITION);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(anon_sym_ARGUMENT_DEFINITION);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(anon_sym_INTERFACE);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(anon_sym_UNION);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(anon_sym_ENUM);
      if (lookahead == '_') ADVANCE(163);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(anon_sym_ENUM_VALUE);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(anon_sym_INPUT_OBJECT);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(anon_sym_INPUT_FIELD_DEFINITION);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'a') ADVANCE(342);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'e') ADVANCE(305);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'e') ADVANCE(307);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'l') ADVANCE(347);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'l') ADVANCE(309);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'l') ADVANCE(343);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'n') ADVANCE(315);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'r') ADVANCE(348);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 's') ADVANCE(341);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'u') ADVANCE(340);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(sym_name);
      if (lookahead == 'u') ADVANCE(344);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(sym_name);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(294);
      if (lookahead == '"') ADVANCE(353);
      if (lookahead != 0) ADVANCE(292);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(294);
      if (lookahead == '"') ADVANCE(351);
      if (lookahead != 0) ADVANCE(292);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(353);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(sym_comma);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(sym_comma);
      if (lookahead == '"') ADVANCE(5);
      if (lookahead != 0) ADVANCE(294);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(sym_comma);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(299);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 0},
  [3] = {.lex_state = 0},
  [4] = {.lex_state = 0},
  [5] = {.lex_state = 0},
  [6] = {.lex_state = 0},
  [7] = {.lex_state = 0},
  [8] = {.lex_state = 0},
  [9] = {.lex_state = 0},
  [10] = {.lex_state = 0},
  [11] = {.lex_state = 0},
  [12] = {.lex_state = 0},
  [13] = {.lex_state = 0},
  [14] = {.lex_state = 0},
  [15] = {.lex_state = 0},
  [16] = {.lex_state = 0},
  [17] = {.lex_state = 0},
  [18] = {.lex_state = 0},
  [19] = {.lex_state = 0},
  [20] = {.lex_state = 0},
  [21] = {.lex_state = 0},
  [22] = {.lex_state = 0},
  [23] = {.lex_state = 0},
  [24] = {.lex_state = 0},
  [25] = {.lex_state = 0},
  [26] = {.lex_state = 0},
  [27] = {.lex_state = 0},
  [28] = {.lex_state = 0},
  [29] = {.lex_state = 0},
  [30] = {.lex_state = 0},
  [31] = {.lex_state = 0},
  [32] = {.lex_state = 0},
  [33] = {.lex_state = 0},
  [34] = {.lex_state = 0},
  [35] = {.lex_state = 0},
  [36] = {.lex_state = 0},
  [37] = {.lex_state = 2},
  [38] = {.lex_state = 2},
  [39] = {.lex_state = 2},
  [40] = {.lex_state = 2},
  [41] = {.lex_state = 2},
  [42] = {.lex_state = 2},
  [43] = {.lex_state = 2},
  [44] = {.lex_state = 0},
  [45] = {.lex_state = 0},
  [46] = {.lex_state = 0},
  [47] = {.lex_state = 0},
  [48] = {.lex_state = 0},
  [49] = {.lex_state = 0},
  [50] = {.lex_state = 0},
  [51] = {.lex_state = 0},
  [52] = {.lex_state = 0},
  [53] = {.lex_state = 0},
  [54] = {.lex_state = 0},
  [55] = {.lex_state = 0},
  [56] = {.lex_state = 0},
  [57] = {.lex_state = 0},
  [58] = {.lex_state = 0},
  [59] = {.lex_state = 0},
  [60] = {.lex_state = 2},
  [61] = {.lex_state = 0},
  [62] = {.lex_state = 0},
  [63] = {.lex_state = 0},
  [64] = {.lex_state = 0},
  [65] = {.lex_state = 0},
  [66] = {.lex_state = 0},
  [67] = {.lex_state = 0},
  [68] = {.lex_state = 0},
  [69] = {.lex_state = 0},
  [70] = {.lex_state = 0},
  [71] = {.lex_state = 0},
  [72] = {.lex_state = 0},
  [73] = {.lex_state = 0},
  [74] = {.lex_state = 0},
  [75] = {.lex_state = 0},
  [76] = {.lex_state = 0},
  [77] = {.lex_state = 0},
  [78] = {.lex_state = 2},
  [79] = {.lex_state = 0},
  [80] = {.lex_state = 0},
  [81] = {.lex_state = 0},
  [82] = {.lex_state = 0},
  [83] = {.lex_state = 2},
  [84] = {.lex_state = 0},
  [85] = {.lex_state = 0},
  [86] = {.lex_state = 0},
  [87] = {.lex_state = 2},
  [88] = {.lex_state = 0},
  [89] = {.lex_state = 0},
  [90] = {.lex_state = 0},
  [91] = {.lex_state = 0},
  [92] = {.lex_state = 0},
  [93] = {.lex_state = 0},
  [94] = {.lex_state = 0},
  [95] = {.lex_state = 0},
  [96] = {.lex_state = 0},
  [97] = {.lex_state = 0},
  [98] = {.lex_state = 0},
  [99] = {.lex_state = 0},
  [100] = {.lex_state = 0},
  [101] = {.lex_state = 0},
  [102] = {.lex_state = 0},
  [103] = {.lex_state = 0},
  [104] = {.lex_state = 0},
  [105] = {.lex_state = 0},
  [106] = {.lex_state = 0},
  [107] = {.lex_state = 0},
  [108] = {.lex_state = 0},
  [109] = {.lex_state = 0},
  [110] = {.lex_state = 0},
  [111] = {.lex_state = 0},
  [112] = {.lex_state = 0},
  [113] = {.lex_state = 0},
  [114] = {.lex_state = 0},
  [115] = {.lex_state = 0},
  [116] = {.lex_state = 0},
  [117] = {.lex_state = 0},
  [118] = {.lex_state = 0},
  [119] = {.lex_state = 0},
  [120] = {.lex_state = 0},
  [121] = {.lex_state = 0},
  [122] = {.lex_state = 0},
  [123] = {.lex_state = 0},
  [124] = {.lex_state = 0},
  [125] = {.lex_state = 0},
  [126] = {.lex_state = 0},
  [127] = {.lex_state = 0},
  [128] = {.lex_state = 0},
  [129] = {.lex_state = 0},
  [130] = {.lex_state = 0},
  [131] = {.lex_state = 0},
  [132] = {.lex_state = 0},
  [133] = {.lex_state = 0},
  [134] = {.lex_state = 0},
  [135] = {.lex_state = 0},
  [136] = {.lex_state = 0},
  [137] = {.lex_state = 0},
  [138] = {.lex_state = 2},
  [139] = {.lex_state = 2},
  [140] = {.lex_state = 2},
  [141] = {.lex_state = 2},
  [142] = {.lex_state = 2},
  [143] = {.lex_state = 2},
  [144] = {.lex_state = 2},
  [145] = {.lex_state = 2},
  [146] = {.lex_state = 2},
  [147] = {.lex_state = 1},
  [148] = {.lex_state = 1},
  [149] = {.lex_state = 4},
  [150] = {.lex_state = 1},
  [151] = {.lex_state = 1},
  [152] = {.lex_state = 1},
  [153] = {.lex_state = 1},
  [154] = {.lex_state = 1},
  [155] = {.lex_state = 1},
  [156] = {.lex_state = 1},
  [157] = {.lex_state = 1},
  [158] = {.lex_state = 1},
  [159] = {.lex_state = 1},
  [160] = {.lex_state = 1},
  [161] = {.lex_state = 1},
  [162] = {.lex_state = 1},
  [163] = {.lex_state = 1},
  [164] = {.lex_state = 1},
  [165] = {.lex_state = 1},
  [166] = {.lex_state = 1},
  [167] = {.lex_state = 1},
  [168] = {.lex_state = 1},
  [169] = {.lex_state = 1},
  [170] = {.lex_state = 0},
  [171] = {.lex_state = 0},
  [172] = {.lex_state = 1},
  [173] = {.lex_state = 1},
  [174] = {.lex_state = 1},
  [175] = {.lex_state = 0},
  [176] = {.lex_state = 1},
  [177] = {.lex_state = 1},
  [178] = {.lex_state = 1},
  [179] = {.lex_state = 1},
  [180] = {.lex_state = 1},
  [181] = {.lex_state = 1},
  [182] = {.lex_state = 1},
  [183] = {.lex_state = 0},
  [184] = {.lex_state = 1},
  [185] = {.lex_state = 1},
  [186] = {.lex_state = 1},
  [187] = {.lex_state = 0},
  [188] = {.lex_state = 1},
  [189] = {.lex_state = 1},
  [190] = {.lex_state = 0},
  [191] = {.lex_state = 1},
  [192] = {.lex_state = 1},
  [193] = {.lex_state = 1},
  [194] = {.lex_state = 0},
  [195] = {.lex_state = 0},
  [196] = {.lex_state = 0},
  [197] = {.lex_state = 1},
  [198] = {.lex_state = 1},
  [199] = {.lex_state = 0},
  [200] = {.lex_state = 0},
  [201] = {.lex_state = 1},
  [202] = {.lex_state = 0},
  [203] = {.lex_state = 0},
  [204] = {.lex_state = 1},
  [205] = {.lex_state = 1},
  [206] = {.lex_state = 1},
  [207] = {.lex_state = 1},
  [208] = {.lex_state = 1},
  [209] = {.lex_state = 0},
  [210] = {.lex_state = 1},
  [211] = {.lex_state = 1},
  [212] = {.lex_state = 1},
  [213] = {.lex_state = 0},
  [214] = {.lex_state = 1},
  [215] = {.lex_state = 1},
  [216] = {.lex_state = 0},
  [217] = {.lex_state = 1},
  [218] = {.lex_state = 1},
  [219] = {.lex_state = 1},
  [220] = {.lex_state = 0},
  [221] = {.lex_state = 1},
  [222] = {.lex_state = 0},
  [223] = {.lex_state = 1},
  [224] = {.lex_state = 1},
  [225] = {.lex_state = 1},
  [226] = {.lex_state = 1},
  [227] = {.lex_state = 0},
  [228] = {.lex_state = 1},
  [229] = {.lex_state = 0},
  [230] = {.lex_state = 0},
  [231] = {.lex_state = 0},
  [232] = {.lex_state = 1},
  [233] = {.lex_state = 0},
  [234] = {.lex_state = 1},
  [235] = {.lex_state = 1},
  [236] = {.lex_state = 1},
  [237] = {.lex_state = 0},
  [238] = {.lex_state = 0},
  [239] = {.lex_state = 0},
  [240] = {.lex_state = 0},
  [241] = {.lex_state = 1},
  [242] = {.lex_state = 1},
  [243] = {.lex_state = 0},
  [244] = {.lex_state = 0},
  [245] = {.lex_state = 1},
  [246] = {.lex_state = 0},
  [247] = {.lex_state = 0},
  [248] = {.lex_state = 1},
  [249] = {.lex_state = 1},
  [250] = {.lex_state = 1},
  [251] = {.lex_state = 1},
  [252] = {.lex_state = 1},
  [253] = {.lex_state = 1},
  [254] = {.lex_state = 0},
  [255] = {.lex_state = 0},
  [256] = {.lex_state = 1},
  [257] = {.lex_state = 0},
  [258] = {.lex_state = 1},
  [259] = {.lex_state = 1},
  [260] = {.lex_state = 1},
  [261] = {.lex_state = 0},
  [262] = {.lex_state = 1},
  [263] = {.lex_state = 1},
  [264] = {.lex_state = 0},
  [265] = {.lex_state = 1},
  [266] = {.lex_state = 1},
  [267] = {.lex_state = 0},
  [268] = {.lex_state = 1},
  [269] = {.lex_state = 0},
  [270] = {.lex_state = 0},
  [271] = {.lex_state = 1},
  [272] = {.lex_state = 1},
  [273] = {.lex_state = 1},
  [274] = {.lex_state = 1},
  [275] = {.lex_state = 1},
  [276] = {.lex_state = 1},
  [277] = {.lex_state = 1},
  [278] = {.lex_state = 1},
  [279] = {.lex_state = 0},
  [280] = {.lex_state = 0},
  [281] = {.lex_state = 1},
  [282] = {.lex_state = 1},
  [283] = {.lex_state = 1},
  [284] = {.lex_state = 1},
  [285] = {.lex_state = 0},
  [286] = {.lex_state = 1},
  [287] = {.lex_state = 1},
  [288] = {.lex_state = 1},
  [289] = {.lex_state = 1},
  [290] = {.lex_state = 1},
  [291] = {.lex_state = 1},
  [292] = {.lex_state = 1},
  [293] = {.lex_state = 0},
  [294] = {.lex_state = 1},
  [295] = {.lex_state = 0},
  [296] = {.lex_state = 1},
  [297] = {.lex_state = 0},
  [298] = {.lex_state = 1},
  [299] = {.lex_state = 0},
  [300] = {.lex_state = 1},
  [301] = {.lex_state = 0},
  [302] = {.lex_state = 0},
  [303] = {.lex_state = 0},
  [304] = {.lex_state = 0},
  [305] = {.lex_state = 0},
  [306] = {.lex_state = 0},
  [307] = {.lex_state = 1},
  [308] = {.lex_state = 1},
  [309] = {.lex_state = 0},
  [310] = {.lex_state = 0},
  [311] = {.lex_state = 0},
  [312] = {.lex_state = 0},
  [313] = {.lex_state = 1},
  [314] = {.lex_state = 1},
  [315] = {.lex_state = 0},
  [316] = {.lex_state = 0},
  [317] = {.lex_state = 1},
  [318] = {.lex_state = 1},
  [319] = {.lex_state = 1},
  [320] = {.lex_state = 1},
  [321] = {.lex_state = 0},
  [322] = {.lex_state = 0},
  [323] = {.lex_state = 1},
  [324] = {.lex_state = 0},
  [325] = {.lex_state = 0},
  [326] = {.lex_state = 4},
  [327] = {.lex_state = 0},
  [328] = {.lex_state = 0},
  [329] = {.lex_state = 1},
  [330] = {.lex_state = 0},
  [331] = {.lex_state = 0},
  [332] = {.lex_state = 1},
  [333] = {.lex_state = 1},
  [334] = {.lex_state = 0},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 0},
  [337] = {.lex_state = 0},
  [338] = {.lex_state = 293},
  [339] = {.lex_state = 1},
  [340] = {.lex_state = 1},
  [341] = {.lex_state = 1},
  [342] = {.lex_state = 0},
  [343] = {.lex_state = 0},
  [344] = {.lex_state = 1},
  [345] = {.lex_state = 297},
  [346] = {.lex_state = 0},
  [347] = {.lex_state = 1},
  [348] = {.lex_state = 1},
  [349] = {.lex_state = 1},
  [350] = {.lex_state = 1},
  [351] = {.lex_state = 0},
  [352] = {.lex_state = 1},
  [353] = {.lex_state = 1},
  [354] = {.lex_state = 1},
  [355] = {.lex_state = 0},
  [356] = {.lex_state = 1},
  [357] = {.lex_state = 1},
  [358] = {.lex_state = 0},
  [359] = {.lex_state = 1},
  [360] = {.lex_state = 0},
  [361] = {.lex_state = 1},
  [362] = {.lex_state = 1},
  [363] = {.lex_state = 0},
  [364] = {.lex_state = 0},
  [365] = {.lex_state = 4},
  [366] = {.lex_state = 1},
  [367] = {.lex_state = 1},
  [368] = {.lex_state = 0},
  [369] = {.lex_state = 0},
  [370] = {.lex_state = 1},
  [371] = {.lex_state = 0},
  [372] = {.lex_state = 0},
  [373] = {.lex_state = 0},
  [374] = {.lex_state = 1},
  [375] = {.lex_state = 0},
  [376] = {.lex_state = 4},
  [377] = {.lex_state = 1},
  [378] = {.lex_state = 1},
  [379] = {.lex_state = 1},
  [380] = {.lex_state = 1},
  [381] = {.lex_state = 0},
  [382] = {.lex_state = 1},
  [383] = {.lex_state = 0},
  [384] = {.lex_state = 4},
  [385] = {.lex_state = 0},
  [386] = {.lex_state = 293},
  [387] = {.lex_state = 297},
  [388] = {.lex_state = 1},
  [389] = {.lex_state = 1},
  [390] = {.lex_state = 293},
  [391] = {.lex_state = 297},
  [392] = {.lex_state = 0},
  [393] = {.lex_state = 293},
  [394] = {.lex_state = 297},
  [395] = {.lex_state = 1},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_schema] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_extend] = ACTIONS(1),
    [anon_sym_scalar] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_input] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_implements] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_query] = ACTIONS(1),
    [anon_sym_mutation] = ACTIONS(1),
    [anon_sym_subscription] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_int_value] = ACTIONS(1),
    [sym_float_value] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_null_value] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_fragment] = ACTIONS(1),
    [anon_sym_on] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_directive] = ACTIONS(1),
    [anon_sym_repeatable] = ACTIONS(1),
    [anon_sym_QUERY] = ACTIONS(1),
    [anon_sym_MUTATION] = ACTIONS(1),
    [anon_sym_SUBSCRIPTION] = ACTIONS(1),
    [anon_sym_FIELD] = ACTIONS(1),
    [anon_sym_FRAGMENT_DEFINITION] = ACTIONS(1),
    [anon_sym_FRAGMENT_SPREAD] = ACTIONS(1),
    [anon_sym_INLINE_FRAGMENT] = ACTIONS(1),
    [anon_sym_VARIABLE_DEFINITION] = ACTIONS(1),
    [anon_sym_SCHEMA] = ACTIONS(1),
    [anon_sym_SCALAR] = ACTIONS(1),
    [anon_sym_OBJECT] = ACTIONS(1),
    [anon_sym_FIELD_DEFINITION] = ACTIONS(1),
    [anon_sym_ARGUMENT_DEFINITION] = ACTIONS(1),
    [anon_sym_INTERFACE] = ACTIONS(1),
    [anon_sym_UNION] = ACTIONS(1),
    [anon_sym_ENUM] = ACTIONS(1),
    [anon_sym_ENUM_VALUE] = ACTIONS(1),
    [anon_sym_INPUT_OBJECT] = ACTIONS(1),
    [anon_sym_INPUT_FIELD_DEFINITION] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(3),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(368),
    [sym_document] = STATE(369),
    [sym_definition] = STATE(2),
    [sym_executable_definition] = STATE(106),
    [sym_type_system_definition] = STATE(106),
    [sym_type_system_extension] = STATE(106),
    [sym_schema_definition] = STATE(95),
    [sym_schema_extension] = STATE(137),
    [sym_type_extension] = STATE(137),
    [sym_scalar_type_extension] = STATE(93),
    [sym_object_type_extension] = STATE(93),
    [sym_interface_type_extension] = STATE(93),
    [sym_union_type_extension] = STATE(93),
    [sym_enum_type_extension] = STATE(93),
    [sym_input_object_type_extension] = STATE(93),
    [sym_operation_definition] = STATE(103),
    [sym_operation_type] = STATE(165),
    [sym_type_definition] = STATE(95),
    [sym_scalar_type_definition] = STATE(135),
    [sym_object_type_definition] = STATE(135),
    [sym_interface_type_definition] = STATE(135),
    [sym_union_type_definition] = STATE(135),
    [sym_enum_type_definition] = STATE(135),
    [sym_input_object_type_definition] = STATE(135),
    [sym_selection_set] = STATE(136),
    [sym_string_value] = STATE(170),
    [sym_fragment_definition] = STATE(103),
    [sym_directive_definition] = STATE(95),
    [sym_description] = STATE(171),
    [aux_sym_document_repeat1] = STATE(2),
    [anon_sym_schema] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_extend] = ACTIONS(9),
    [anon_sym_scalar] = ACTIONS(11),
    [anon_sym_type] = ACTIONS(13),
    [anon_sym_interface] = ACTIONS(15),
    [anon_sym_union] = ACTIONS(17),
    [anon_sym_enum] = ACTIONS(19),
    [anon_sym_input] = ACTIONS(21),
    [anon_sym_query] = ACTIONS(23),
    [anon_sym_mutation] = ACTIONS(23),
    [anon_sym_subscription] = ACTIONS(23),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(25),
    [anon_sym_DQUOTE] = ACTIONS(27),
    [anon_sym_fragment] = ACTIONS(29),
    [anon_sym_directive] = ACTIONS(31),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 27,
    ACTIONS(5), 1,
      anon_sym_schema,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(9), 1,
      anon_sym_extend,
    ACTIONS(11), 1,
      anon_sym_scalar,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_interface,
    ACTIONS(17), 1,
      anon_sym_union,
    ACTIONS(19), 1,
      anon_sym_enum,
    ACTIONS(21), 1,
      anon_sym_input,
    ACTIONS(25), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(27), 1,
      anon_sym_DQUOTE,
    ACTIONS(29), 1,
      anon_sym_fragment,
    ACTIONS(31), 1,
      anon_sym_directive,
    ACTIONS(33), 1,
      ts_builtin_sym_end,
    STATE(136), 1,
      sym_selection_set,
    STATE(165), 1,
      sym_operation_type,
    STATE(170), 1,
      sym_string_value,
    STATE(171), 1,
      sym_description,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(3), 2,
      sym_definition,
      aux_sym_document_repeat1,
    STATE(103), 2,
      sym_operation_definition,
      sym_fragment_definition,
    STATE(137), 2,
      sym_schema_extension,
      sym_type_extension,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
    STATE(95), 3,
      sym_schema_definition,
      sym_type_definition,
      sym_directive_definition,
    STATE(106), 3,
      sym_executable_definition,
      sym_type_system_definition,
      sym_type_system_extension,
    STATE(93), 6,
      sym_scalar_type_extension,
      sym_object_type_extension,
      sym_interface_type_extension,
      sym_union_type_extension,
      sym_enum_type_extension,
      sym_input_object_type_extension,
    STATE(135), 6,
      sym_scalar_type_definition,
      sym_object_type_definition,
      sym_interface_type_definition,
      sym_union_type_definition,
      sym_enum_type_definition,
      sym_input_object_type_definition,
  [102] = 27,
    ACTIONS(35), 1,
      ts_builtin_sym_end,
    ACTIONS(37), 1,
      anon_sym_schema,
    ACTIONS(40), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 1,
      anon_sym_extend,
    ACTIONS(46), 1,
      anon_sym_scalar,
    ACTIONS(49), 1,
      anon_sym_type,
    ACTIONS(52), 1,
      anon_sym_interface,
    ACTIONS(55), 1,
      anon_sym_union,
    ACTIONS(58), 1,
      anon_sym_enum,
    ACTIONS(61), 1,
      anon_sym_input,
    ACTIONS(67), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(70), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_fragment,
    ACTIONS(76), 1,
      anon_sym_directive,
    STATE(136), 1,
      sym_selection_set,
    STATE(165), 1,
      sym_operation_type,
    STATE(170), 1,
      sym_string_value,
    STATE(171), 1,
      sym_description,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(3), 2,
      sym_definition,
      aux_sym_document_repeat1,
    STATE(103), 2,
      sym_operation_definition,
      sym_fragment_definition,
    STATE(137), 2,
      sym_schema_extension,
      sym_type_extension,
    ACTIONS(64), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
    STATE(95), 3,
      sym_schema_definition,
      sym_type_definition,
      sym_directive_definition,
    STATE(106), 3,
      sym_executable_definition,
      sym_type_system_definition,
      sym_type_system_extension,
    STATE(93), 6,
      sym_scalar_type_extension,
      sym_object_type_extension,
      sym_interface_type_extension,
      sym_union_type_extension,
      sym_enum_type_extension,
      sym_input_object_type_extension,
    STATE(135), 6,
      sym_scalar_type_definition,
      sym_object_type_definition,
      sym_interface_type_definition,
      sym_union_type_definition,
      sym_enum_type_definition,
      sym_input_object_type_definition,
  [204] = 10,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(83), 1,
      anon_sym_implements,
    ACTIONS(85), 1,
      anon_sym_DQUOTE,
    ACTIONS(87), 1,
      anon_sym_AT,
    STATE(21), 1,
      sym_implements_interfaces,
    STATE(64), 1,
      sym_directives,
    STATE(104), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(79), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [251] = 10,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(83), 1,
      anon_sym_implements,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      anon_sym_DQUOTE,
    STATE(23), 1,
      sym_implements_interfaces,
    STATE(71), 1,
      sym_directives,
    STATE(131), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(89), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [298] = 10,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(83), 1,
      anon_sym_implements,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(95), 1,
      anon_sym_DQUOTE,
    STATE(24), 1,
      sym_implements_interfaces,
    STATE(84), 1,
      sym_directives,
    STATE(92), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(93), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [345] = 10,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(83), 1,
      anon_sym_implements,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    STATE(22), 1,
      sym_implements_interfaces,
    STATE(86), 1,
      sym_directives,
    STATE(98), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(97), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [392] = 9,
    ACTIONS(101), 1,
      anon_sym_PIPE,
    ACTIONS(105), 1,
      anon_sym_FIELD,
    ACTIONS(109), 1,
      anon_sym_ENUM,
    STATE(69), 1,
      sym_directive_locations,
    STATE(70), 1,
      sym_directive_location,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(90), 2,
      sym_executable_directive_location,
      sym_type_system_directive_location,
    ACTIONS(103), 7,
      anon_sym_QUERY,
      anon_sym_MUTATION,
      anon_sym_SUBSCRIPTION,
      anon_sym_FRAGMENT_DEFINITION,
      anon_sym_FRAGMENT_SPREAD,
      anon_sym_INLINE_FRAGMENT,
      anon_sym_VARIABLE_DEFINITION,
    ACTIONS(107), 10,
      anon_sym_SCHEMA,
      anon_sym_SCALAR,
      anon_sym_OBJECT,
      anon_sym_FIELD_DEFINITION,
      anon_sym_ARGUMENT_DEFINITION,
      anon_sym_INTERFACE,
      anon_sym_UNION,
      anon_sym_ENUM_VALUE,
      anon_sym_INPUT_OBJECT,
      anon_sym_INPUT_FIELD_DEFINITION,
  [437] = 10,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(83), 1,
      anon_sym_implements,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(113), 1,
      anon_sym_DQUOTE,
    STATE(17), 1,
      sym_implements_interfaces,
    STATE(55), 1,
      sym_directives,
    STATE(117), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(111), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [484] = 9,
    ACTIONS(101), 1,
      anon_sym_PIPE,
    ACTIONS(105), 1,
      anon_sym_FIELD,
    ACTIONS(109), 1,
      anon_sym_ENUM,
    STATE(70), 1,
      sym_directive_location,
    STATE(77), 1,
      sym_directive_locations,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(90), 2,
      sym_executable_directive_location,
      sym_type_system_directive_location,
    ACTIONS(103), 7,
      anon_sym_QUERY,
      anon_sym_MUTATION,
      anon_sym_SUBSCRIPTION,
      anon_sym_FRAGMENT_DEFINITION,
      anon_sym_FRAGMENT_SPREAD,
      anon_sym_INLINE_FRAGMENT,
      anon_sym_VARIABLE_DEFINITION,
    ACTIONS(107), 10,
      anon_sym_SCHEMA,
      anon_sym_SCALAR,
      anon_sym_OBJECT,
      anon_sym_FIELD_DEFINITION,
      anon_sym_ARGUMENT_DEFINITION,
      anon_sym_INTERFACE,
      anon_sym_UNION,
      anon_sym_ENUM_VALUE,
      anon_sym_INPUT_OBJECT,
      anon_sym_INPUT_FIELD_DEFINITION,
  [529] = 10,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(83), 1,
      anon_sym_implements,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(117), 1,
      anon_sym_DQUOTE,
    STATE(16), 1,
      sym_implements_interfaces,
    STATE(75), 1,
      sym_directives,
    STATE(91), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(115), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [576] = 9,
    ACTIONS(101), 1,
      anon_sym_PIPE,
    ACTIONS(105), 1,
      anon_sym_FIELD,
    ACTIONS(109), 1,
      anon_sym_ENUM,
    STATE(70), 1,
      sym_directive_location,
    STATE(81), 1,
      sym_directive_locations,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(90), 2,
      sym_executable_directive_location,
      sym_type_system_directive_location,
    ACTIONS(103), 7,
      anon_sym_QUERY,
      anon_sym_MUTATION,
      anon_sym_SUBSCRIPTION,
      anon_sym_FRAGMENT_DEFINITION,
      anon_sym_FRAGMENT_SPREAD,
      anon_sym_INLINE_FRAGMENT,
      anon_sym_VARIABLE_DEFINITION,
    ACTIONS(107), 10,
      anon_sym_SCHEMA,
      anon_sym_SCALAR,
      anon_sym_OBJECT,
      anon_sym_FIELD_DEFINITION,
      anon_sym_ARGUMENT_DEFINITION,
      anon_sym_INTERFACE,
      anon_sym_UNION,
      anon_sym_ENUM_VALUE,
      anon_sym_INPUT_OBJECT,
      anon_sym_INPUT_FIELD_DEFINITION,
  [621] = 9,
    ACTIONS(101), 1,
      anon_sym_PIPE,
    ACTIONS(105), 1,
      anon_sym_FIELD,
    ACTIONS(109), 1,
      anon_sym_ENUM,
    STATE(70), 1,
      sym_directive_location,
    STATE(85), 1,
      sym_directive_locations,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(90), 2,
      sym_executable_directive_location,
      sym_type_system_directive_location,
    ACTIONS(103), 7,
      anon_sym_QUERY,
      anon_sym_MUTATION,
      anon_sym_SUBSCRIPTION,
      anon_sym_FRAGMENT_DEFINITION,
      anon_sym_FRAGMENT_SPREAD,
      anon_sym_INLINE_FRAGMENT,
      anon_sym_VARIABLE_DEFINITION,
    ACTIONS(107), 10,
      anon_sym_SCHEMA,
      anon_sym_SCALAR,
      anon_sym_OBJECT,
      anon_sym_FIELD_DEFINITION,
      anon_sym_ARGUMENT_DEFINITION,
      anon_sym_INTERFACE,
      anon_sym_UNION,
      anon_sym_ENUM_VALUE,
      anon_sym_INPUT_OBJECT,
      anon_sym_INPUT_FIELD_DEFINITION,
  [666] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(121), 1,
      anon_sym_EQ,
    ACTIONS(123), 1,
      anon_sym_DQUOTE,
    STATE(53), 1,
      sym_directives,
    STATE(82), 1,
      sym_union_member_types,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(119), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [708] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_DQUOTE,
    STATE(47), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    STATE(48), 2,
      sym_input_fields_definition,
      aux_sym_input_object_type_extension_repeat1,
    ACTIONS(125), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [750] = 9,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(95), 1,
      anon_sym_DQUOTE,
    ACTIONS(131), 1,
      anon_sym_AMP,
    STATE(84), 1,
      sym_directives,
    STATE(92), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(93), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [794] = 9,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(131), 1,
      anon_sym_AMP,
    STATE(86), 1,
      sym_directives,
    STATE(98), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(97), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [838] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(121), 1,
      anon_sym_EQ,
    ACTIONS(135), 1,
      anon_sym_DQUOTE,
    STATE(46), 1,
      sym_directives,
    STATE(57), 1,
      sym_union_member_types,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(133), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [880] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(121), 1,
      anon_sym_EQ,
    ACTIONS(139), 1,
      anon_sym_DQUOTE,
    STATE(50), 1,
      sym_directives,
    STATE(56), 1,
      sym_union_member_types,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(137), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [922] = 3,
    ACTIONS(143), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(141), 22,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_RBRACK,
      anon_sym_fragment,
      anon_sym_AT,
      anon_sym_directive,
      anon_sym_BANG,
  [954] = 9,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(131), 1,
      anon_sym_AMP,
    ACTIONS(147), 1,
      anon_sym_DQUOTE,
    STATE(62), 1,
      sym_directives,
    STATE(129), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(145), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [998] = 9,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(131), 1,
      anon_sym_AMP,
    ACTIONS(151), 1,
      anon_sym_DQUOTE,
    STATE(73), 1,
      sym_directives,
    STATE(97), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(149), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1042] = 9,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(131), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      anon_sym_DQUOTE,
    STATE(61), 1,
      sym_directives,
    STATE(127), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(153), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1086] = 9,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(131), 1,
      anon_sym_AMP,
    ACTIONS(159), 1,
      anon_sym_DQUOTE,
    STATE(72), 1,
      sym_directives,
    STATE(96), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(157), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1130] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(163), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_DQUOTE,
    STATE(58), 1,
      sym_directives,
    STATE(105), 1,
      sym_enum_values_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(161), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1171] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(59), 1,
      sym_directives,
    STATE(108), 1,
      sym_input_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(167), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1212] = 7,
    ACTIONS(105), 1,
      anon_sym_FIELD,
    ACTIONS(109), 1,
      anon_sym_ENUM,
    STATE(76), 1,
      sym_directive_location,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(90), 2,
      sym_executable_directive_location,
      sym_type_system_directive_location,
    ACTIONS(103), 7,
      anon_sym_QUERY,
      anon_sym_MUTATION,
      anon_sym_SUBSCRIPTION,
      anon_sym_FRAGMENT_DEFINITION,
      anon_sym_FRAGMENT_SPREAD,
      anon_sym_INLINE_FRAGMENT,
      anon_sym_VARIABLE_DEFINITION,
    ACTIONS(107), 10,
      anon_sym_SCHEMA,
      anon_sym_SCALAR,
      anon_sym_OBJECT,
      anon_sym_FIELD_DEFINITION,
      anon_sym_ARGUMENT_DEFINITION,
      anon_sym_INTERFACE,
      anon_sym_UNION,
      anon_sym_ENUM_VALUE,
      anon_sym_INPUT_OBJECT,
      anon_sym_INPUT_FIELD_DEFINITION,
  [1251] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(163), 1,
      anon_sym_LBRACE,
    ACTIONS(173), 1,
      anon_sym_DQUOTE,
    STATE(89), 1,
      sym_directives,
    STATE(130), 1,
      sym_enum_values_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(171), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1292] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(163), 1,
      anon_sym_LBRACE,
    ACTIONS(177), 1,
      anon_sym_DQUOTE,
    STATE(65), 1,
      sym_directives,
    STATE(123), 1,
      sym_enum_values_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(175), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1333] = 8,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(181), 1,
      anon_sym_DQUOTE,
    STATE(79), 1,
      sym_directives,
    STATE(132), 1,
      sym_input_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(179), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1374] = 7,
    ACTIONS(105), 1,
      anon_sym_FIELD,
    ACTIONS(109), 1,
      anon_sym_ENUM,
    STATE(80), 1,
      sym_directive_location,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(90), 2,
      sym_executable_directive_location,
      sym_type_system_directive_location,
    ACTIONS(103), 7,
      anon_sym_QUERY,
      anon_sym_MUTATION,
      anon_sym_SUBSCRIPTION,
      anon_sym_FRAGMENT_DEFINITION,
      anon_sym_FRAGMENT_SPREAD,
      anon_sym_INLINE_FRAGMENT,
      anon_sym_VARIABLE_DEFINITION,
    ACTIONS(107), 10,
      anon_sym_SCHEMA,
      anon_sym_SCALAR,
      anon_sym_OBJECT,
      anon_sym_FIELD_DEFINITION,
      anon_sym_ARGUMENT_DEFINITION,
      anon_sym_INTERFACE,
      anon_sym_UNION,
      anon_sym_ENUM_VALUE,
      anon_sym_INPUT_OBJECT,
      anon_sym_INPUT_FIELD_DEFINITION,
  [1413] = 6,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(185), 1,
      anon_sym_DQUOTE,
    STATE(116), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(183), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1449] = 6,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(189), 1,
      anon_sym_DQUOTE,
    STATE(102), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(187), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1485] = 5,
    ACTIONS(193), 1,
      anon_sym_LPAREN,
    ACTIONS(195), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(191), 18,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_EQ,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_AT,
      anon_sym_directive,
  [1519] = 5,
    ACTIONS(87), 1,
      anon_sym_AT,
    ACTIONS(199), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(36), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(197), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_EQ,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1553] = 5,
    ACTIONS(203), 1,
      anon_sym_DQUOTE,
    ACTIONS(205), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(36), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(201), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_EQ,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1587] = 13,
    ACTIONS(208), 1,
      anon_sym_LBRACE,
    ACTIONS(210), 1,
      anon_sym_DOLLAR,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(214), 1,
      anon_sym_DQUOTE,
    ACTIONS(218), 1,
      sym_float_value,
    ACTIONS(222), 1,
      anon_sym_LBRACK,
    ACTIONS(224), 1,
      anon_sym_RBRACK,
    ACTIONS(226), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(216), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(220), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(40), 2,
      sym_value,
      aux_sym_list_value_repeat1,
    STATE(140), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [1636] = 13,
    ACTIONS(208), 1,
      anon_sym_LBRACE,
    ACTIONS(210), 1,
      anon_sym_DOLLAR,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(214), 1,
      anon_sym_DQUOTE,
    ACTIONS(218), 1,
      sym_float_value,
    ACTIONS(222), 1,
      anon_sym_LBRACK,
    ACTIONS(226), 1,
      sym_name,
    ACTIONS(228), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(216), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(220), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(40), 2,
      sym_value,
      aux_sym_list_value_repeat1,
    STATE(140), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [1685] = 13,
    ACTIONS(208), 1,
      anon_sym_LBRACE,
    ACTIONS(210), 1,
      anon_sym_DOLLAR,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(214), 1,
      anon_sym_DQUOTE,
    ACTIONS(218), 1,
      sym_float_value,
    ACTIONS(222), 1,
      anon_sym_LBRACK,
    ACTIONS(226), 1,
      sym_name,
    ACTIONS(230), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(216), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(220), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(37), 2,
      sym_value,
      aux_sym_list_value_repeat1,
    STATE(140), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [1734] = 13,
    ACTIONS(232), 1,
      anon_sym_LBRACE,
    ACTIONS(235), 1,
      anon_sym_DOLLAR,
    ACTIONS(238), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(241), 1,
      anon_sym_DQUOTE,
    ACTIONS(247), 1,
      sym_float_value,
    ACTIONS(253), 1,
      anon_sym_LBRACK,
    ACTIONS(256), 1,
      anon_sym_RBRACK,
    ACTIONS(258), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(244), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(250), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(40), 2,
      sym_value,
      aux_sym_list_value_repeat1,
    STATE(140), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [1783] = 13,
    ACTIONS(208), 1,
      anon_sym_LBRACE,
    ACTIONS(210), 1,
      anon_sym_DOLLAR,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(214), 1,
      anon_sym_DQUOTE,
    ACTIONS(218), 1,
      sym_float_value,
    ACTIONS(222), 1,
      anon_sym_LBRACK,
    ACTIONS(226), 1,
      sym_name,
    ACTIONS(261), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(216), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(220), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(42), 2,
      sym_value,
      aux_sym_list_value_repeat1,
    STATE(140), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [1832] = 13,
    ACTIONS(208), 1,
      anon_sym_LBRACE,
    ACTIONS(210), 1,
      anon_sym_DOLLAR,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(214), 1,
      anon_sym_DQUOTE,
    ACTIONS(218), 1,
      sym_float_value,
    ACTIONS(222), 1,
      anon_sym_LBRACK,
    ACTIONS(226), 1,
      sym_name,
    ACTIONS(263), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(216), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(220), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(40), 2,
      sym_value,
      aux_sym_list_value_repeat1,
    STATE(140), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [1881] = 13,
    ACTIONS(208), 1,
      anon_sym_LBRACE,
    ACTIONS(210), 1,
      anon_sym_DOLLAR,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(214), 1,
      anon_sym_DQUOTE,
    ACTIONS(218), 1,
      sym_float_value,
    ACTIONS(222), 1,
      anon_sym_LBRACK,
    ACTIONS(226), 1,
      sym_name,
    ACTIONS(265), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(216), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(220), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(38), 2,
      sym_value,
      aux_sym_list_value_repeat1,
    STATE(140), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [1930] = 5,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(272), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(44), 2,
      sym_input_fields_definition,
      aux_sym_input_object_type_extension_repeat1,
    ACTIONS(267), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [1962] = 3,
    ACTIONS(276), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(274), 18,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_EQ,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_AT,
      anon_sym_directive,
  [1990] = 5,
    ACTIONS(121), 1,
      anon_sym_EQ,
    ACTIONS(280), 1,
      anon_sym_DQUOTE,
    STATE(63), 1,
      sym_union_member_types,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(278), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2022] = 5,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(284), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(51), 2,
      sym_input_fields_definition,
      aux_sym_input_object_type_extension_repeat1,
    ACTIONS(282), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2054] = 5,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(284), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(44), 2,
      sym_input_fields_definition,
      aux_sym_input_object_type_extension_repeat1,
    ACTIONS(282), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2086] = 3,
    ACTIONS(288), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(286), 18,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_AMP,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_AT,
      anon_sym_directive,
  [2114] = 5,
    ACTIONS(121), 1,
      anon_sym_EQ,
    ACTIONS(292), 1,
      anon_sym_DQUOTE,
    STATE(74), 1,
      sym_union_member_types,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(290), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2146] = 5,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(296), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(44), 2,
      sym_input_fields_definition,
      aux_sym_input_object_type_extension_repeat1,
    ACTIONS(294), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2178] = 3,
    ACTIONS(300), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(298), 18,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_AMP,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_AT,
      anon_sym_directive,
  [2206] = 5,
    ACTIONS(121), 1,
      anon_sym_EQ,
    ACTIONS(139), 1,
      anon_sym_DQUOTE,
    STATE(56), 1,
      sym_union_member_types,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(137), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2238] = 3,
    ACTIONS(304), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(302), 18,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_EQ,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_AT,
      anon_sym_directive,
  [2266] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(97), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2297] = 4,
    ACTIONS(292), 1,
      anon_sym_DQUOTE,
    ACTIONS(306), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(290), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2326] = 4,
    ACTIONS(280), 1,
      anon_sym_DQUOTE,
    ACTIONS(306), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(278), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2355] = 5,
    ACTIONS(163), 1,
      anon_sym_LBRACE,
    ACTIONS(310), 1,
      anon_sym_DQUOTE,
    STATE(110), 1,
      sym_enum_values_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(308), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2386] = 5,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(314), 1,
      anon_sym_DQUOTE,
    STATE(111), 1,
      sym_input_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(312), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2417] = 12,
    ACTIONS(316), 1,
      anon_sym_LBRACE,
    ACTIONS(318), 1,
      anon_sym_DOLLAR,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(326), 1,
      sym_float_value,
    ACTIONS(330), 1,
      anon_sym_LBRACK,
    ACTIONS(332), 1,
      sym_name,
    STATE(313), 1,
      sym_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(324), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(328), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(219), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [2462] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(336), 1,
      anon_sym_DQUOTE,
    STATE(114), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(334), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2493] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(340), 1,
      anon_sym_DQUOTE,
    STATE(115), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(338), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2524] = 4,
    ACTIONS(306), 1,
      anon_sym_PIPE,
    ACTIONS(344), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(342), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2553] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(147), 1,
      anon_sym_DQUOTE,
    STATE(129), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(145), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2584] = 5,
    ACTIONS(163), 1,
      anon_sym_LBRACE,
    ACTIONS(348), 1,
      anon_sym_DQUOTE,
    STATE(133), 1,
      sym_enum_values_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(346), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2615] = 3,
    ACTIONS(352), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(350), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2642] = 3,
    ACTIONS(356), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(354), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2669] = 3,
    ACTIONS(360), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(358), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2696] = 4,
    ACTIONS(364), 1,
      anon_sym_PIPE,
    ACTIONS(366), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(362), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2725] = 3,
    ACTIONS(370), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(368), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2752] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(155), 1,
      anon_sym_DQUOTE,
    STATE(127), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(153), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2783] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(374), 1,
      anon_sym_DQUOTE,
    STATE(120), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(372), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2814] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(378), 1,
      anon_sym_DQUOTE,
    STATE(121), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(376), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2845] = 4,
    ACTIONS(306), 1,
      anon_sym_PIPE,
    ACTIONS(382), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(380), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2874] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(95), 1,
      anon_sym_DQUOTE,
    STATE(92), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(93), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2905] = 3,
    ACTIONS(386), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(384), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2932] = 4,
    ACTIONS(364), 1,
      anon_sym_PIPE,
    ACTIONS(390), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(388), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [2961] = 12,
    ACTIONS(392), 1,
      anon_sym_LBRACE,
    ACTIONS(394), 1,
      anon_sym_DOLLAR,
    ACTIONS(396), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(398), 1,
      anon_sym_DQUOTE,
    ACTIONS(402), 1,
      sym_float_value,
    ACTIONS(406), 1,
      anon_sym_LBRACK,
    ACTIONS(408), 1,
      sym_name,
    STATE(299), 1,
      sym_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(400), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(404), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(249), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [3006] = 5,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(108), 1,
      sym_input_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(167), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3037] = 3,
    ACTIONS(412), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(410), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3064] = 4,
    ACTIONS(364), 1,
      anon_sym_PIPE,
    ACTIONS(416), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(414), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3093] = 4,
    ACTIONS(139), 1,
      anon_sym_DQUOTE,
    ACTIONS(306), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(137), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3122] = 12,
    ACTIONS(392), 1,
      anon_sym_LBRACE,
    ACTIONS(394), 1,
      anon_sym_DOLLAR,
    ACTIONS(396), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(398), 1,
      anon_sym_DQUOTE,
    ACTIONS(402), 1,
      sym_float_value,
    ACTIONS(406), 1,
      anon_sym_LBRACK,
    ACTIONS(408), 1,
      sym_name,
    STATE(320), 1,
      sym_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(400), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(404), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(249), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [3167] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(159), 1,
      anon_sym_DQUOTE,
    STATE(96), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(157), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3198] = 4,
    ACTIONS(364), 1,
      anon_sym_PIPE,
    ACTIONS(420), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(418), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3227] = 5,
    ACTIONS(81), 1,
      anon_sym_LBRACE,
    ACTIONS(151), 1,
      anon_sym_DQUOTE,
    STATE(97), 1,
      sym_fields_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(149), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3258] = 12,
    ACTIONS(316), 1,
      anon_sym_LBRACE,
    ACTIONS(318), 1,
      anon_sym_DOLLAR,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(326), 1,
      sym_float_value,
    ACTIONS(330), 1,
      anon_sym_LBRACK,
    ACTIONS(332), 1,
      sym_name,
    STATE(218), 1,
      sym_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(324), 2,
      sym_int_value,
      sym_null_value,
    ACTIONS(328), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(219), 6,
      sym_variable,
      sym_string_value,
      sym_boolean_value,
      sym_enum_value,
      sym_list_value,
      sym_object_value,
  [3303] = 3,
    ACTIONS(424), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(422), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3330] = 5,
    ACTIONS(163), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_DQUOTE,
    STATE(105), 1,
      sym_enum_values_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(161), 15,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3361] = 3,
    ACTIONS(428), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(426), 17,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_PIPE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3388] = 3,
    ACTIONS(95), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(93), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3414] = 3,
    ACTIONS(159), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(157), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3440] = 3,
    ACTIONS(432), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(430), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3466] = 3,
    ACTIONS(436), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(434), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3492] = 3,
    ACTIONS(440), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(438), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3518] = 3,
    ACTIONS(374), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(372), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3544] = 3,
    ACTIONS(378), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(376), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3570] = 3,
    ACTIONS(151), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(149), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3596] = 3,
    ACTIONS(444), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(442), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3622] = 3,
    ACTIONS(448), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(446), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3648] = 3,
    ACTIONS(452), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(450), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3674] = 3,
    ACTIONS(185), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(183), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3700] = 3,
    ACTIONS(456), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(454), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3726] = 3,
    ACTIONS(147), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(145), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3752] = 3,
    ACTIONS(310), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(308), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3778] = 3,
    ACTIONS(460), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(458), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3804] = 3,
    ACTIONS(464), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(462), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3830] = 3,
    ACTIONS(314), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(312), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3856] = 3,
    ACTIONS(468), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(466), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3882] = 3,
    ACTIONS(472), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(470), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3908] = 3,
    ACTIONS(476), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(474), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3934] = 3,
    ACTIONS(480), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(478), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3960] = 3,
    ACTIONS(484), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(482), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [3986] = 3,
    ACTIONS(488), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(486), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4012] = 3,
    ACTIONS(492), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(490), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4038] = 3,
    ACTIONS(496), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(494), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4064] = 3,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(97), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4090] = 3,
    ACTIONS(500), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(498), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4116] = 3,
    ACTIONS(504), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(502), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4142] = 3,
    ACTIONS(508), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(506), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4168] = 3,
    ACTIONS(512), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(510), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4194] = 3,
    ACTIONS(516), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(514), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4220] = 3,
    ACTIONS(348), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(346), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4246] = 3,
    ACTIONS(520), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(518), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4272] = 3,
    ACTIONS(524), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(522), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4298] = 3,
    ACTIONS(528), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(526), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4324] = 3,
    ACTIONS(336), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(334), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4350] = 3,
    ACTIONS(532), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(530), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4376] = 3,
    ACTIONS(340), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(338), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4402] = 3,
    ACTIONS(165), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(161), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4428] = 3,
    ACTIONS(155), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(153), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4454] = 3,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(167), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4480] = 3,
    ACTIONS(536), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(534), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4506] = 3,
    ACTIONS(540), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(538), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4532] = 3,
    ACTIONS(544), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(542), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4558] = 3,
    ACTIONS(548), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(546), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4584] = 3,
    ACTIONS(552), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(550), 16,
      ts_builtin_sym_end,
      anon_sym_schema,
      anon_sym_LBRACE,
      anon_sym_extend,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_fragment,
      anon_sym_directive,
  [4610] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(554), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(556), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4631] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(558), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(560), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4652] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(562), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(564), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4673] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(566), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(568), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4694] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(570), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(572), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4715] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(574), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(576), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4736] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(578), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(580), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4757] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(582), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(584), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4778] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(586), 6,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_float_value,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(588), 6,
      anon_sym_DQUOTE,
      sym_int_value,
      anon_sym_true,
      anon_sym_false,
      sym_null_value,
      sym_name,
  [4799] = 8,
    ACTIONS(592), 1,
      anon_sym_EQ,
    ACTIONS(594), 1,
      anon_sym_DQUOTE,
    ACTIONS(596), 1,
      anon_sym_AT,
    STATE(152), 1,
      sym_default_value,
    STATE(235), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(590), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [4829] = 8,
    ACTIONS(592), 1,
      anon_sym_EQ,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(600), 1,
      anon_sym_DQUOTE,
    STATE(161), 1,
      sym_default_value,
    STATE(232), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(598), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [4859] = 10,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    ACTIONS(604), 1,
      anon_sym_on,
    ACTIONS(606), 1,
      sym_name,
    STATE(189), 1,
      sym_fragment_name,
    STATE(209), 1,
      sym_type_condition,
    STATE(292), 1,
      sym_selection_set,
    STATE(315), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [4892] = 5,
    ACTIONS(195), 1,
      anon_sym_DQUOTE,
    ACTIONS(608), 1,
      anon_sym_LPAREN,
    STATE(179), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(191), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_DOT_DOT_DOT,
      anon_sym_AT,
      sym_name,
  [4915] = 9,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    ACTIONS(608), 1,
      anon_sym_LPAREN,
    ACTIONS(612), 1,
      anon_sym_COLON,
    STATE(197), 1,
      sym_arguments,
    STATE(245), 1,
      sym_directive,
    STATE(291), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(610), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [4946] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(616), 1,
      anon_sym_DQUOTE,
    STATE(236), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(614), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [4970] = 7,
    ACTIONS(618), 1,
      anon_sym_RBRACE,
    ACTIONS(620), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(622), 1,
      sym_name,
    STATE(344), 1,
      sym_alias,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(163), 2,
      sym_selection,
      aux_sym_selection_set_repeat1,
    STATE(284), 3,
      sym_field,
      sym_fragment_spread,
      sym_inline_fragment,
  [4996] = 9,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(624), 1,
      anon_sym_RBRACE,
    ACTIONS(626), 1,
      sym_name,
    STATE(167), 1,
      sym_enum_value,
    STATE(318), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(164), 2,
      sym_enum_value_definition,
      aux_sym_enum_values_definition_repeat1,
  [5026] = 4,
    ACTIONS(630), 1,
      anon_sym_DQUOTE,
    ACTIONS(632), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(628), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_RBRACK,
      anon_sym_AT,
      sym_name,
  [5046] = 8,
    ACTIONS(636), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(639), 1,
      anon_sym_DQUOTE,
    ACTIONS(642), 1,
      sym_name,
    STATE(354), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(634), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(156), 2,
      sym_input_value_definition,
      aux_sym_input_fields_definition_repeat1,
  [5074] = 3,
    ACTIONS(647), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(645), 8,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_BANG,
      sym_name,
  [5092] = 5,
    ACTIONS(203), 1,
      anon_sym_DQUOTE,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(158), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(201), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [5114] = 8,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    ACTIONS(608), 1,
      anon_sym_LPAREN,
    STATE(192), 1,
      sym_arguments,
    STATE(242), 1,
      sym_directive,
    STATE(286), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(652), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [5142] = 7,
    ACTIONS(620), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(622), 1,
      sym_name,
    ACTIONS(654), 1,
      anon_sym_RBRACE,
    STATE(344), 1,
      sym_alias,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(163), 2,
      sym_selection,
      aux_sym_selection_set_repeat1,
    STATE(284), 3,
      sym_field,
      sym_fragment_spread,
      sym_inline_fragment,
  [5168] = 6,
    ACTIONS(594), 1,
      anon_sym_DQUOTE,
    ACTIONS(596), 1,
      anon_sym_AT,
    STATE(235), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(590), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [5192] = 5,
    ACTIONS(199), 1,
      anon_sym_DQUOTE,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(158), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(197), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [5214] = 7,
    ACTIONS(656), 1,
      anon_sym_RBRACE,
    ACTIONS(658), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(661), 1,
      sym_name,
    STATE(344), 1,
      sym_alias,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(163), 2,
      sym_selection,
      aux_sym_selection_set_repeat1,
    STATE(284), 3,
      sym_field,
      sym_fragment_spread,
      sym_inline_fragment,
  [5240] = 9,
    ACTIONS(664), 1,
      anon_sym_RBRACE,
    ACTIONS(666), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(669), 1,
      anon_sym_DQUOTE,
    ACTIONS(672), 1,
      sym_name,
    STATE(167), 1,
      sym_enum_value,
    STATE(318), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(164), 2,
      sym_enum_value_definition,
      aux_sym_enum_values_definition_repeat1,
  [5270] = 9,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(677), 1,
      sym_name,
    STATE(118), 1,
      sym_selection_set,
    STATE(220), 1,
      sym_variable_definitions,
    STATE(302), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [5300] = 8,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(679), 1,
      anon_sym_RPAREN,
    ACTIONS(681), 1,
      sym_name,
    STATE(354), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(156), 2,
      sym_input_value_definition,
      aux_sym_input_fields_definition_repeat1,
  [5327] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(685), 1,
      anon_sym_DQUOTE,
    STATE(259), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(683), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [5350] = 8,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(681), 1,
      sym_name,
    ACTIONS(687), 1,
      anon_sym_RBRACE,
    STATE(354), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(156), 2,
      sym_input_value_definition,
      aux_sym_input_fields_definition_repeat1,
  [5377] = 3,
    ACTIONS(304), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(302), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_DOT_DOT_DOT,
      anon_sym_AT,
      sym_name,
  [5394] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(689), 8,
      anon_sym_schema,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_directive,
  [5409] = 9,
    ACTIONS(691), 1,
      anon_sym_schema,
    ACTIONS(693), 1,
      anon_sym_scalar,
    ACTIONS(695), 1,
      anon_sym_type,
    ACTIONS(697), 1,
      anon_sym_interface,
    ACTIONS(699), 1,
      anon_sym_union,
    ACTIONS(701), 1,
      anon_sym_enum,
    ACTIONS(703), 1,
      anon_sym_input,
    ACTIONS(705), 1,
      anon_sym_directive,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [5438] = 8,
    ACTIONS(707), 1,
      anon_sym_RBRACE,
    ACTIONS(709), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(712), 1,
      anon_sym_DQUOTE,
    ACTIONS(715), 1,
      sym_name,
    STATE(366), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(172), 2,
      sym_field_definition,
      aux_sym_fields_definition_repeat1,
  [5465] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(720), 1,
      anon_sym_DQUOTE,
    STATE(266), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(718), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [5488] = 8,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(626), 1,
      sym_name,
    STATE(167), 1,
      sym_enum_value,
    STATE(318), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(154), 2,
      sym_enum_value_definition,
      aux_sym_enum_values_definition_repeat1,
  [5515] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(724), 1,
      anon_sym_EQ,
    ACTIONS(726), 1,
      anon_sym_AT,
    ACTIONS(728), 1,
      sym_comma,
    STATE(203), 1,
      sym_default_value,
    STATE(304), 1,
      sym_directives,
    ACTIONS(722), 2,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
    STATE(237), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [5542] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(732), 1,
      anon_sym_DQUOTE,
    STATE(272), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(730), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [5565] = 6,
    ACTIONS(620), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(622), 1,
      sym_name,
    STATE(344), 1,
      sym_alias,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(153), 2,
      sym_selection,
      aux_sym_selection_set_repeat1,
    STATE(284), 3,
      sym_field,
      sym_fragment_spread,
      sym_inline_fragment,
  [5588] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(736), 1,
      anon_sym_DQUOTE,
    STATE(260), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(734), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [5611] = 3,
    ACTIONS(276), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(274), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_DOT_DOT_DOT,
      anon_sym_AT,
      sym_name,
  [5628] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(740), 1,
      anon_sym_DQUOTE,
    STATE(263), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(738), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [5651] = 3,
    ACTIONS(630), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(628), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_RBRACK,
      anon_sym_AT,
      sym_name,
  [5668] = 3,
    ACTIONS(744), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(742), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_RBRACK,
      anon_sym_AT,
      sym_name,
  [5685] = 8,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    STATE(134), 1,
      sym_selection_set,
    STATE(222), 1,
      sym_variable_definitions,
    STATE(322), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [5712] = 3,
    ACTIONS(143), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(141), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      anon_sym_BANG,
      sym_name,
  [5729] = 8,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(746), 1,
      anon_sym_RBRACE,
    ACTIONS(748), 1,
      sym_name,
    STATE(366), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(172), 2,
      sym_field_definition,
      aux_sym_fields_definition_repeat1,
  [5756] = 6,
    ACTIONS(620), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(622), 1,
      sym_name,
    STATE(344), 1,
      sym_alias,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(160), 2,
      sym_selection,
      aux_sym_selection_set_repeat1,
    STATE(284), 3,
      sym_field,
      sym_fragment_spread,
      sym_inline_fragment,
  [5779] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(586), 8,
      anon_sym_schema,
      anon_sym_scalar,
      anon_sym_type,
      anon_sym_interface,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_input,
      anon_sym_directive,
  [5794] = 7,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(681), 1,
      sym_name,
    STATE(354), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(166), 2,
      sym_input_value_definition,
      aux_sym_input_fields_definition_repeat1,
  [5818] = 5,
    ACTIONS(596), 1,
      anon_sym_AT,
    STATE(281), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(162), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(750), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [5838] = 5,
    ACTIONS(752), 1,
      anon_sym_RBRACE,
    STATE(385), 1,
      sym_operation_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(199), 2,
      sym_root_operation_type_definition,
      aux_sym_schema_definition_repeat1,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [5858] = 7,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(681), 1,
      sym_name,
    STATE(354), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(168), 2,
      sym_input_value_definition,
      aux_sym_input_fields_definition_repeat1,
  [5882] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    STATE(228), 1,
      sym_directive,
    STATE(296), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(754), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [5904] = 3,
    ACTIONS(584), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(582), 6,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [5920] = 5,
    ACTIONS(756), 1,
      anon_sym_RBRACE,
    STATE(385), 1,
      sym_operation_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(199), 2,
      sym_root_operation_type_definition,
      aux_sym_schema_definition_repeat1,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [5940] = 5,
    ACTIONS(758), 1,
      anon_sym_RBRACE,
    STATE(385), 1,
      sym_operation_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(199), 2,
      sym_root_operation_type_definition,
      aux_sym_schema_definition_repeat1,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [5960] = 8,
    ACTIONS(760), 1,
      anon_sym_schema,
    ACTIONS(762), 1,
      anon_sym_scalar,
    ACTIONS(764), 1,
      anon_sym_type,
    ACTIONS(766), 1,
      anon_sym_interface,
    ACTIONS(768), 1,
      anon_sym_union,
    ACTIONS(770), 1,
      anon_sym_enum,
    ACTIONS(772), 1,
      anon_sym_input,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [5986] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    STATE(242), 1,
      sym_directive,
    STATE(286), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(652), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [6008] = 7,
    ACTIONS(320), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(322), 1,
      anon_sym_DQUOTE,
    ACTIONS(748), 1,
      sym_name,
    STATE(366), 1,
      sym_description,
    STATE(379), 1,
      sym_string_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(185), 2,
      sym_field_definition,
      aux_sym_fields_definition_repeat1,
  [6032] = 5,
    ACTIONS(774), 1,
      anon_sym_RBRACE,
    STATE(385), 1,
      sym_operation_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(199), 2,
      sym_root_operation_type_definition,
      aux_sym_schema_definition_repeat1,
    ACTIONS(776), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [6052] = 6,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(596), 1,
      anon_sym_AT,
    STATE(109), 1,
      sym_selection_set,
    STATE(324), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6073] = 6,
    ACTIONS(779), 1,
      anon_sym_LBRACK,
    ACTIONS(781), 1,
      sym_name,
    STATE(147), 1,
      sym_type,
    STATE(181), 1,
      sym_non_null_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(155), 2,
      sym_named_type,
      sym_list_type,
  [6094] = 4,
    STATE(385), 1,
      sym_operation_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(190), 2,
      sym_root_operation_type_definition,
      aux_sym_schema_definition_repeat1,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [6111] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(726), 1,
      anon_sym_AT,
    ACTIONS(785), 1,
      sym_comma,
    STATE(325), 1,
      sym_directives,
    ACTIONS(783), 2,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
    STATE(237), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6132] = 3,
    ACTIONS(560), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(558), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6147] = 3,
    ACTIONS(572), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(570), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6162] = 6,
    ACTIONS(779), 1,
      anon_sym_LBRACK,
    ACTIONS(781), 1,
      sym_name,
    STATE(148), 1,
      sym_type,
    STATE(181), 1,
      sym_non_null_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(155), 2,
      sym_named_type,
      sym_list_type,
  [6183] = 6,
    ACTIONS(787), 1,
      anon_sym_LBRACK,
    ACTIONS(789), 1,
      sym_name,
    STATE(175), 1,
      sym_type,
    STATE(254), 1,
      sym_non_null_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(247), 2,
      sym_named_type,
      sym_list_type,
  [6204] = 6,
    ACTIONS(779), 1,
      anon_sym_LBRACK,
    ACTIONS(781), 1,
      sym_name,
    STATE(180), 1,
      sym_type,
    STATE(181), 1,
      sym_non_null_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(155), 2,
      sym_named_type,
      sym_list_type,
  [6225] = 6,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    STATE(282), 1,
      sym_selection_set,
    STATE(305), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6246] = 6,
    ACTIONS(779), 1,
      anon_sym_LBRACK,
    ACTIONS(791), 1,
      sym_name,
    STATE(181), 1,
      sym_non_null_type,
    STATE(372), 1,
      sym_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(155), 2,
      sym_named_type,
      sym_list_type,
  [6267] = 3,
    ACTIONS(576), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(574), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6282] = 3,
    ACTIONS(580), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(578), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6297] = 4,
    STATE(385), 1,
      sym_operation_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(194), 2,
      sym_root_operation_type_definition,
      aux_sym_schema_definition_repeat1,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [6314] = 3,
    ACTIONS(588), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(586), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6329] = 6,
    ACTIONS(779), 1,
      anon_sym_LBRACK,
    ACTIONS(781), 1,
      sym_name,
    STATE(176), 1,
      sym_type,
    STATE(181), 1,
      sym_non_null_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(155), 2,
      sym_named_type,
      sym_list_type,
  [6350] = 4,
    STATE(385), 1,
      sym_operation_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(195), 2,
      sym_root_operation_type_definition,
      aux_sym_schema_definition_repeat1,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [6367] = 6,
    ACTIONS(779), 1,
      anon_sym_LBRACK,
    ACTIONS(791), 1,
      sym_name,
    STATE(181), 1,
      sym_non_null_type,
    STATE(371), 1,
      sym_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(155), 2,
      sym_named_type,
      sym_list_type,
  [6388] = 3,
    ACTIONS(795), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(793), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6403] = 3,
    ACTIONS(564), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(562), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6418] = 6,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(596), 1,
      anon_sym_AT,
    STATE(134), 1,
      sym_selection_set,
    STATE(322), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6439] = 3,
    ACTIONS(568), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(566), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6454] = 6,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(596), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_selection_set,
    STATE(306), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6475] = 3,
    ACTIONS(556), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(554), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_AT,
      sym_name,
  [6490] = 6,
    ACTIONS(779), 1,
      anon_sym_LBRACK,
    ACTIONS(781), 1,
      sym_name,
    STATE(178), 1,
      sym_type,
    STATE(181), 1,
      sym_non_null_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(155), 2,
      sym_named_type,
      sym_list_type,
  [6511] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(566), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6523] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(586), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6535] = 5,
    ACTIONS(318), 1,
      anon_sym_DOLLAR,
    ACTIONS(797), 1,
      anon_sym_RPAREN,
    STATE(334), 1,
      sym_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(231), 2,
      sym_variable_definition,
      aux_sym_variable_definitions_repeat1,
  [6553] = 4,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    STATE(298), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(799), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [6569] = 4,
    STATE(335), 1,
      sym_root_operation_type_definition,
    STATE(385), 1,
      sym_operation_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [6585] = 5,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(801), 1,
      anon_sym_LBRACE,
    STATE(381), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6603] = 5,
    ACTIONS(803), 1,
      anon_sym_RPAREN,
    ACTIONS(805), 1,
      anon_sym_DOLLAR,
    STATE(334), 1,
      sym_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(231), 2,
      sym_variable_definition,
      aux_sym_variable_definitions_repeat1,
  [6621] = 3,
    ACTIONS(594), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(590), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [6635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(645), 6,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_BANG,
      sym_comma,
  [6647] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(808), 5,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_name,
  [6659] = 3,
    ACTIONS(616), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(614), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [6673] = 3,
    ACTIONS(812), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(810), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [6687] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(726), 1,
      anon_sym_AT,
    STATE(239), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(197), 3,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      sym_comma,
  [6703] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_LPAREN,
    STATE(285), 1,
      sym_arguments,
    ACTIONS(191), 4,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [6719] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(816), 1,
      anon_sym_AT,
    STATE(239), 2,
      sym_directive,
      aux_sym_directives_repeat1,
    ACTIONS(201), 3,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      sym_comma,
  [6735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(141), 6,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_BANG,
      sym_comma,
  [6747] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(582), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6759] = 4,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    STATE(296), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(754), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [6775] = 4,
    STATE(385), 1,
      sym_operation_type,
    STATE(392), 1,
      sym_root_operation_type_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(23), 3,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [6791] = 5,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(819), 1,
      anon_sym_LBRACE,
    STATE(331), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6809] = 4,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    STATE(286), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(652), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [6825] = 5,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(821), 1,
      anon_sym_LBRACE,
    STATE(351), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(257), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6843] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 1,
      anon_sym_BANG,
    ACTIONS(628), 5,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [6857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(554), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6869] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(562), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(558), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6893] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(570), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6905] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(574), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6917] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(578), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_name,
      sym_comma,
  [6929] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(628), 5,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [6940] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(825), 4,
      anon_sym_RBRACE,
      anon_sym_query,
      anon_sym_mutation,
      anon_sym_subscription,
  [6951] = 4,
    ACTIONS(827), 1,
      anon_sym_RPAREN,
    ACTIONS(829), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(256), 2,
      sym_argument,
      aux_sym_arguments_repeat1,
  [6966] = 4,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(596), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(261), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [6981] = 4,
    ACTIONS(832), 1,
      anon_sym_RBRACE,
    ACTIONS(834), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(258), 2,
      sym_object_field,
      aux_sym_object_value_repeat1,
  [6996] = 3,
    ACTIONS(720), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(718), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [7009] = 3,
    ACTIONS(740), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(738), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [7022] = 4,
    ACTIONS(201), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(261), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [7037] = 4,
    ACTIONS(837), 1,
      anon_sym_RPAREN,
    ACTIONS(839), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(256), 2,
      sym_argument,
      aux_sym_arguments_repeat1,
  [7052] = 3,
    ACTIONS(843), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(841), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [7065] = 5,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(847), 1,
      anon_sym_on,
    ACTIONS(849), 1,
      anon_sym_repeatable,
    STATE(311), 1,
      sym_arguments_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7082] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(851), 4,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      anon_sym_AT,
      sym_name,
  [7093] = 3,
    ACTIONS(855), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(853), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [7106] = 4,
    ACTIONS(87), 1,
      anon_sym_AT,
    STATE(128), 1,
      sym_directives,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(35), 2,
      sym_directive,
      aux_sym_directives_repeat1,
  [7121] = 4,
    ACTIONS(857), 1,
      anon_sym_RBRACE,
    ACTIONS(859), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(271), 2,
      sym_object_field,
      aux_sym_object_value_repeat1,
  [7136] = 4,
    ACTIONS(318), 1,
      anon_sym_DOLLAR,
    STATE(334), 1,
      sym_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(227), 2,
      sym_variable_definition,
      aux_sym_variable_definitions_repeat1,
  [7151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(742), 5,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [7162] = 4,
    ACTIONS(859), 1,
      sym_name,
    ACTIONS(861), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(258), 2,
      sym_object_field,
      aux_sym_object_value_repeat1,
  [7177] = 3,
    ACTIONS(736), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(734), 3,
      anon_sym_RBRACE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_name,
  [7190] = 4,
    ACTIONS(839), 1,
      sym_name,
    ACTIONS(863), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(256), 2,
      sym_argument,
      aux_sym_arguments_repeat1,
  [7205] = 4,
    ACTIONS(859), 1,
      sym_name,
    ACTIONS(865), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(275), 2,
      sym_object_field,
      aux_sym_object_value_repeat1,
  [7220] = 4,
    ACTIONS(859), 1,
      sym_name,
    ACTIONS(867), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(258), 2,
      sym_object_field,
      aux_sym_object_value_repeat1,
  [7235] = 4,
    ACTIONS(839), 1,
      sym_name,
    ACTIONS(869), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(256), 2,
      sym_argument,
      aux_sym_arguments_repeat1,
  [7250] = 4,
    ACTIONS(859), 1,
      sym_name,
    ACTIONS(871), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(278), 2,
      sym_object_field,
      aux_sym_object_value_repeat1,
  [7265] = 4,
    ACTIONS(859), 1,
      sym_name,
    ACTIONS(873), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(258), 2,
      sym_object_field,
      aux_sym_object_value_repeat1,
  [7280] = 5,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(875), 1,
      anon_sym_on,
    ACTIONS(877), 1,
      anon_sym_repeatable,
    STATE(303), 1,
      sym_arguments_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7297] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(879), 3,
      anon_sym_COLON,
      anon_sym_on,
      anon_sym_repeatable,
  [7307] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(881), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7317] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(883), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7327] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(522), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7337] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(885), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7347] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(274), 4,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [7357] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(754), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7367] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(887), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7377] = 4,
    ACTIONS(306), 1,
      anon_sym_PIPE,
    ACTIONS(791), 1,
      sym_name,
    STATE(88), 1,
      sym_named_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7391] = 4,
    ACTIONS(131), 1,
      anon_sym_AMP,
    ACTIONS(791), 1,
      sym_name,
    STATE(49), 1,
      sym_named_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7405] = 3,
    ACTIONS(839), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(262), 2,
      sym_argument,
      aux_sym_arguments_repeat1,
  [7417] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(652), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7427] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(889), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7437] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(302), 4,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [7447] = 3,
    ACTIONS(839), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(276), 2,
      sym_argument,
      aux_sym_arguments_repeat1,
  [7459] = 4,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(891), 1,
      anon_sym_COLON,
    STATE(355), 1,
      sym_arguments_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7473] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(799), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7483] = 4,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(893), 1,
      anon_sym_COLON,
    STATE(358), 1,
      sym_arguments_definition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7497] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(895), 3,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT_DOT,
      sym_name,
  [7507] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 4,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [7517] = 3,
    ACTIONS(839), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    STATE(273), 2,
      sym_argument,
      aux_sym_arguments_repeat1,
  [7529] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(783), 2,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
  [7538] = 3,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(134), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7549] = 3,
    ACTIONS(897), 1,
      anon_sym_on,
    ACTIONS(899), 1,
      anon_sym_repeatable,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(785), 1,
      sym_comma,
    ACTIONS(783), 2,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
  [7571] = 3,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    STATE(287), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7582] = 3,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(107), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7593] = 3,
    ACTIONS(791), 1,
      sym_name,
    STATE(255), 1,
      sym_named_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7604] = 3,
    ACTIONS(791), 1,
      sym_name,
    STATE(310), 1,
      sym_named_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7615] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(901), 2,
      anon_sym_LBRACE,
      anon_sym_AT,
  [7624] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(903), 2,
      anon_sym_LBRACE,
      anon_sym_AT,
  [7633] = 3,
    ACTIONS(875), 1,
      anon_sym_on,
    ACTIONS(877), 1,
      anon_sym_repeatable,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7644] = 3,
    ACTIONS(905), 1,
      anon_sym_on,
    STATE(200), 1,
      sym_type_condition,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7655] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(907), 2,
      anon_sym_RPAREN,
      sym_name,
  [7664] = 3,
    ACTIONS(909), 1,
      sym_name,
    STATE(312), 1,
      sym_fragment_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7675] = 3,
    ACTIONS(602), 1,
      anon_sym_LBRACE,
    STATE(282), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7686] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(911), 2,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
  [7695] = 3,
    ACTIONS(791), 1,
      sym_name,
    STATE(66), 1,
      sym_named_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7706] = 3,
    ACTIONS(626), 1,
      sym_name,
    STATE(173), 1,
      sym_enum_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7717] = 3,
    ACTIONS(791), 1,
      sym_name,
    STATE(52), 1,
      sym_named_type,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7728] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(915), 1,
      sym_comma,
    ACTIONS(913), 2,
      anon_sym_RBRACE,
      sym_name,
  [7739] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(917), 2,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
  [7748] = 3,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(112), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7759] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
    ACTIONS(919), 2,
      anon_sym_RBRACE,
      sym_name,
  [7768] = 3,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(101), 1,
      sym_selection_set,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(921), 1,
      sym_comma,
    ACTIONS(917), 2,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
  [7790] = 2,
    ACTIONS(923), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7798] = 2,
    ACTIONS(923), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7806] = 2,
    ACTIONS(925), 1,
      anon_sym_on,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7814] = 2,
    ACTIONS(927), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7822] = 2,
    ACTIONS(929), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7830] = 2,
    ACTIONS(931), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7838] = 2,
    ACTIONS(933), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7846] = 2,
    ACTIONS(935), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7854] = 2,
    ACTIONS(937), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7862] = 2,
    ACTIONS(939), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7870] = 2,
    ACTIONS(875), 1,
      anon_sym_on,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7878] = 2,
    ACTIONS(851), 1,
      anon_sym_on,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7886] = 2,
    ACTIONS(941), 1,
      aux_sym_string_value_token1,
    ACTIONS(943), 2,
      sym_comment,
      sym_comma,
  [7894] = 2,
    ACTIONS(945), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7902] = 2,
    ACTIONS(947), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7910] = 2,
    ACTIONS(949), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7918] = 2,
    ACTIONS(951), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7926] = 2,
    ACTIONS(953), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7934] = 2,
    ACTIONS(955), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7942] = 2,
    ACTIONS(957), 1,
      aux_sym_string_value_token2,
    ACTIONS(943), 2,
      sym_comment,
      sym_comma,
  [7950] = 2,
    ACTIONS(959), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7958] = 2,
    ACTIONS(961), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7966] = 2,
    ACTIONS(963), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7974] = 2,
    ACTIONS(965), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7982] = 2,
    ACTIONS(967), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7990] = 2,
    ACTIONS(969), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [7998] = 2,
    ACTIONS(971), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8006] = 2,
    ACTIONS(973), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8014] = 2,
    ACTIONS(975), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8022] = 2,
    ACTIONS(977), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8030] = 2,
    ACTIONS(979), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8038] = 2,
    ACTIONS(981), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8046] = 2,
    ACTIONS(891), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8054] = 2,
    ACTIONS(983), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8062] = 2,
    ACTIONS(985), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8070] = 2,
    ACTIONS(987), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8078] = 2,
    ACTIONS(989), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8086] = 2,
    ACTIONS(991), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8094] = 2,
    ACTIONS(993), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8102] = 2,
    ACTIONS(993), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8110] = 2,
    ACTIONS(995), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8118] = 2,
    ACTIONS(997), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8126] = 2,
    ACTIONS(999), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8134] = 2,
    ACTIONS(1001), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8142] = 2,
    ACTIONS(1003), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8150] = 2,
    ACTIONS(1005), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8158] = 2,
    ACTIONS(1007), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8166] = 2,
    ACTIONS(897), 1,
      anon_sym_on,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8174] = 2,
    ACTIONS(1009), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8182] = 2,
    ACTIONS(1011), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8190] = 2,
    ACTIONS(1011), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8198] = 2,
    ACTIONS(1013), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8206] = 2,
    ACTIONS(1015), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8214] = 2,
    ACTIONS(689), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8222] = 2,
    ACTIONS(1017), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8230] = 2,
    ACTIONS(821), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8238] = 2,
    ACTIONS(1019), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8246] = 2,
    ACTIONS(1021), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8254] = 2,
    ACTIONS(1021), 1,
      anon_sym_DQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8262] = 2,
    ACTIONS(1023), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8270] = 2,
    ACTIONS(1025), 1,
      aux_sym_string_value_token1,
    ACTIONS(943), 2,
      sym_comment,
      sym_comma,
  [8278] = 2,
    ACTIONS(1027), 1,
      aux_sym_string_value_token2,
    ACTIONS(943), 2,
      sym_comment,
      sym_comma,
  [8286] = 2,
    ACTIONS(1029), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8294] = 2,
    ACTIONS(1031), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8302] = 2,
    ACTIONS(1033), 1,
      aux_sym_string_value_token1,
    ACTIONS(943), 2,
      sym_comment,
      sym_comma,
  [8310] = 2,
    ACTIONS(1035), 1,
      aux_sym_string_value_token2,
    ACTIONS(943), 2,
      sym_comment,
      sym_comma,
  [8318] = 2,
    ACTIONS(1037), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
  [8326] = 2,
    ACTIONS(1039), 1,
      aux_sym_string_value_token1,
    ACTIONS(943), 2,
      sym_comment,
      sym_comma,
  [8334] = 2,
    ACTIONS(1041), 1,
      aux_sym_string_value_token2,
    ACTIONS(943), 2,
      sym_comment,
      sym_comma,
  [8342] = 2,
    ACTIONS(1043), 1,
      sym_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_comma,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 102,
  [SMALL_STATE(4)] = 204,
  [SMALL_STATE(5)] = 251,
  [SMALL_STATE(6)] = 298,
  [SMALL_STATE(7)] = 345,
  [SMALL_STATE(8)] = 392,
  [SMALL_STATE(9)] = 437,
  [SMALL_STATE(10)] = 484,
  [SMALL_STATE(11)] = 529,
  [SMALL_STATE(12)] = 576,
  [SMALL_STATE(13)] = 621,
  [SMALL_STATE(14)] = 666,
  [SMALL_STATE(15)] = 708,
  [SMALL_STATE(16)] = 750,
  [SMALL_STATE(17)] = 794,
  [SMALL_STATE(18)] = 838,
  [SMALL_STATE(19)] = 880,
  [SMALL_STATE(20)] = 922,
  [SMALL_STATE(21)] = 954,
  [SMALL_STATE(22)] = 998,
  [SMALL_STATE(23)] = 1042,
  [SMALL_STATE(24)] = 1086,
  [SMALL_STATE(25)] = 1130,
  [SMALL_STATE(26)] = 1171,
  [SMALL_STATE(27)] = 1212,
  [SMALL_STATE(28)] = 1251,
  [SMALL_STATE(29)] = 1292,
  [SMALL_STATE(30)] = 1333,
  [SMALL_STATE(31)] = 1374,
  [SMALL_STATE(32)] = 1413,
  [SMALL_STATE(33)] = 1449,
  [SMALL_STATE(34)] = 1485,
  [SMALL_STATE(35)] = 1519,
  [SMALL_STATE(36)] = 1553,
  [SMALL_STATE(37)] = 1587,
  [SMALL_STATE(38)] = 1636,
  [SMALL_STATE(39)] = 1685,
  [SMALL_STATE(40)] = 1734,
  [SMALL_STATE(41)] = 1783,
  [SMALL_STATE(42)] = 1832,
  [SMALL_STATE(43)] = 1881,
  [SMALL_STATE(44)] = 1930,
  [SMALL_STATE(45)] = 1962,
  [SMALL_STATE(46)] = 1990,
  [SMALL_STATE(47)] = 2022,
  [SMALL_STATE(48)] = 2054,
  [SMALL_STATE(49)] = 2086,
  [SMALL_STATE(50)] = 2114,
  [SMALL_STATE(51)] = 2146,
  [SMALL_STATE(52)] = 2178,
  [SMALL_STATE(53)] = 2206,
  [SMALL_STATE(54)] = 2238,
  [SMALL_STATE(55)] = 2266,
  [SMALL_STATE(56)] = 2297,
  [SMALL_STATE(57)] = 2326,
  [SMALL_STATE(58)] = 2355,
  [SMALL_STATE(59)] = 2386,
  [SMALL_STATE(60)] = 2417,
  [SMALL_STATE(61)] = 2462,
  [SMALL_STATE(62)] = 2493,
  [SMALL_STATE(63)] = 2524,
  [SMALL_STATE(64)] = 2553,
  [SMALL_STATE(65)] = 2584,
  [SMALL_STATE(66)] = 2615,
  [SMALL_STATE(67)] = 2642,
  [SMALL_STATE(68)] = 2669,
  [SMALL_STATE(69)] = 2696,
  [SMALL_STATE(70)] = 2725,
  [SMALL_STATE(71)] = 2752,
  [SMALL_STATE(72)] = 2783,
  [SMALL_STATE(73)] = 2814,
  [SMALL_STATE(74)] = 2845,
  [SMALL_STATE(75)] = 2874,
  [SMALL_STATE(76)] = 2905,
  [SMALL_STATE(77)] = 2932,
  [SMALL_STATE(78)] = 2961,
  [SMALL_STATE(79)] = 3006,
  [SMALL_STATE(80)] = 3037,
  [SMALL_STATE(81)] = 3064,
  [SMALL_STATE(82)] = 3093,
  [SMALL_STATE(83)] = 3122,
  [SMALL_STATE(84)] = 3167,
  [SMALL_STATE(85)] = 3198,
  [SMALL_STATE(86)] = 3227,
  [SMALL_STATE(87)] = 3258,
  [SMALL_STATE(88)] = 3303,
  [SMALL_STATE(89)] = 3330,
  [SMALL_STATE(90)] = 3361,
  [SMALL_STATE(91)] = 3388,
  [SMALL_STATE(92)] = 3414,
  [SMALL_STATE(93)] = 3440,
  [SMALL_STATE(94)] = 3466,
  [SMALL_STATE(95)] = 3492,
  [SMALL_STATE(96)] = 3518,
  [SMALL_STATE(97)] = 3544,
  [SMALL_STATE(98)] = 3570,
  [SMALL_STATE(99)] = 3596,
  [SMALL_STATE(100)] = 3622,
  [SMALL_STATE(101)] = 3648,
  [SMALL_STATE(102)] = 3674,
  [SMALL_STATE(103)] = 3700,
  [SMALL_STATE(104)] = 3726,
  [SMALL_STATE(105)] = 3752,
  [SMALL_STATE(106)] = 3778,
  [SMALL_STATE(107)] = 3804,
  [SMALL_STATE(108)] = 3830,
  [SMALL_STATE(109)] = 3856,
  [SMALL_STATE(110)] = 3882,
  [SMALL_STATE(111)] = 3908,
  [SMALL_STATE(112)] = 3934,
  [SMALL_STATE(113)] = 3960,
  [SMALL_STATE(114)] = 3986,
  [SMALL_STATE(115)] = 4012,
  [SMALL_STATE(116)] = 4038,
  [SMALL_STATE(117)] = 4064,
  [SMALL_STATE(118)] = 4090,
  [SMALL_STATE(119)] = 4116,
  [SMALL_STATE(120)] = 4142,
  [SMALL_STATE(121)] = 4168,
  [SMALL_STATE(122)] = 4194,
  [SMALL_STATE(123)] = 4220,
  [SMALL_STATE(124)] = 4246,
  [SMALL_STATE(125)] = 4272,
  [SMALL_STATE(126)] = 4298,
  [SMALL_STATE(127)] = 4324,
  [SMALL_STATE(128)] = 4350,
  [SMALL_STATE(129)] = 4376,
  [SMALL_STATE(130)] = 4402,
  [SMALL_STATE(131)] = 4428,
  [SMALL_STATE(132)] = 4454,
  [SMALL_STATE(133)] = 4480,
  [SMALL_STATE(134)] = 4506,
  [SMALL_STATE(135)] = 4532,
  [SMALL_STATE(136)] = 4558,
  [SMALL_STATE(137)] = 4584,
  [SMALL_STATE(138)] = 4610,
  [SMALL_STATE(139)] = 4631,
  [SMALL_STATE(140)] = 4652,
  [SMALL_STATE(141)] = 4673,
  [SMALL_STATE(142)] = 4694,
  [SMALL_STATE(143)] = 4715,
  [SMALL_STATE(144)] = 4736,
  [SMALL_STATE(145)] = 4757,
  [SMALL_STATE(146)] = 4778,
  [SMALL_STATE(147)] = 4799,
  [SMALL_STATE(148)] = 4829,
  [SMALL_STATE(149)] = 4859,
  [SMALL_STATE(150)] = 4892,
  [SMALL_STATE(151)] = 4915,
  [SMALL_STATE(152)] = 4946,
  [SMALL_STATE(153)] = 4970,
  [SMALL_STATE(154)] = 4996,
  [SMALL_STATE(155)] = 5026,
  [SMALL_STATE(156)] = 5046,
  [SMALL_STATE(157)] = 5074,
  [SMALL_STATE(158)] = 5092,
  [SMALL_STATE(159)] = 5114,
  [SMALL_STATE(160)] = 5142,
  [SMALL_STATE(161)] = 5168,
  [SMALL_STATE(162)] = 5192,
  [SMALL_STATE(163)] = 5214,
  [SMALL_STATE(164)] = 5240,
  [SMALL_STATE(165)] = 5270,
  [SMALL_STATE(166)] = 5300,
  [SMALL_STATE(167)] = 5327,
  [SMALL_STATE(168)] = 5350,
  [SMALL_STATE(169)] = 5377,
  [SMALL_STATE(170)] = 5394,
  [SMALL_STATE(171)] = 5409,
  [SMALL_STATE(172)] = 5438,
  [SMALL_STATE(173)] = 5465,
  [SMALL_STATE(174)] = 5488,
  [SMALL_STATE(175)] = 5515,
  [SMALL_STATE(176)] = 5542,
  [SMALL_STATE(177)] = 5565,
  [SMALL_STATE(178)] = 5588,
  [SMALL_STATE(179)] = 5611,
  [SMALL_STATE(180)] = 5628,
  [SMALL_STATE(181)] = 5651,
  [SMALL_STATE(182)] = 5668,
  [SMALL_STATE(183)] = 5685,
  [SMALL_STATE(184)] = 5712,
  [SMALL_STATE(185)] = 5729,
  [SMALL_STATE(186)] = 5756,
  [SMALL_STATE(187)] = 5779,
  [SMALL_STATE(188)] = 5794,
  [SMALL_STATE(189)] = 5818,
  [SMALL_STATE(190)] = 5838,
  [SMALL_STATE(191)] = 5858,
  [SMALL_STATE(192)] = 5882,
  [SMALL_STATE(193)] = 5904,
  [SMALL_STATE(194)] = 5920,
  [SMALL_STATE(195)] = 5940,
  [SMALL_STATE(196)] = 5960,
  [SMALL_STATE(197)] = 5986,
  [SMALL_STATE(198)] = 6008,
  [SMALL_STATE(199)] = 6032,
  [SMALL_STATE(200)] = 6052,
  [SMALL_STATE(201)] = 6073,
  [SMALL_STATE(202)] = 6094,
  [SMALL_STATE(203)] = 6111,
  [SMALL_STATE(204)] = 6132,
  [SMALL_STATE(205)] = 6147,
  [SMALL_STATE(206)] = 6162,
  [SMALL_STATE(207)] = 6183,
  [SMALL_STATE(208)] = 6204,
  [SMALL_STATE(209)] = 6225,
  [SMALL_STATE(210)] = 6246,
  [SMALL_STATE(211)] = 6267,
  [SMALL_STATE(212)] = 6282,
  [SMALL_STATE(213)] = 6297,
  [SMALL_STATE(214)] = 6314,
  [SMALL_STATE(215)] = 6329,
  [SMALL_STATE(216)] = 6350,
  [SMALL_STATE(217)] = 6367,
  [SMALL_STATE(218)] = 6388,
  [SMALL_STATE(219)] = 6403,
  [SMALL_STATE(220)] = 6418,
  [SMALL_STATE(221)] = 6439,
  [SMALL_STATE(222)] = 6454,
  [SMALL_STATE(223)] = 6475,
  [SMALL_STATE(224)] = 6490,
  [SMALL_STATE(225)] = 6511,
  [SMALL_STATE(226)] = 6523,
  [SMALL_STATE(227)] = 6535,
  [SMALL_STATE(228)] = 6553,
  [SMALL_STATE(229)] = 6569,
  [SMALL_STATE(230)] = 6585,
  [SMALL_STATE(231)] = 6603,
  [SMALL_STATE(232)] = 6621,
  [SMALL_STATE(233)] = 6635,
  [SMALL_STATE(234)] = 6647,
  [SMALL_STATE(235)] = 6659,
  [SMALL_STATE(236)] = 6673,
  [SMALL_STATE(237)] = 6687,
  [SMALL_STATE(238)] = 6703,
  [SMALL_STATE(239)] = 6719,
  [SMALL_STATE(240)] = 6735,
  [SMALL_STATE(241)] = 6747,
  [SMALL_STATE(242)] = 6759,
  [SMALL_STATE(243)] = 6775,
  [SMALL_STATE(244)] = 6791,
  [SMALL_STATE(245)] = 6809,
  [SMALL_STATE(246)] = 6825,
  [SMALL_STATE(247)] = 6843,
  [SMALL_STATE(248)] = 6857,
  [SMALL_STATE(249)] = 6869,
  [SMALL_STATE(250)] = 6881,
  [SMALL_STATE(251)] = 6893,
  [SMALL_STATE(252)] = 6905,
  [SMALL_STATE(253)] = 6917,
  [SMALL_STATE(254)] = 6929,
  [SMALL_STATE(255)] = 6940,
  [SMALL_STATE(256)] = 6951,
  [SMALL_STATE(257)] = 6966,
  [SMALL_STATE(258)] = 6981,
  [SMALL_STATE(259)] = 6996,
  [SMALL_STATE(260)] = 7009,
  [SMALL_STATE(261)] = 7022,
  [SMALL_STATE(262)] = 7037,
  [SMALL_STATE(263)] = 7052,
  [SMALL_STATE(264)] = 7065,
  [SMALL_STATE(265)] = 7082,
  [SMALL_STATE(266)] = 7093,
  [SMALL_STATE(267)] = 7106,
  [SMALL_STATE(268)] = 7121,
  [SMALL_STATE(269)] = 7136,
  [SMALL_STATE(270)] = 7151,
  [SMALL_STATE(271)] = 7162,
  [SMALL_STATE(272)] = 7177,
  [SMALL_STATE(273)] = 7190,
  [SMALL_STATE(274)] = 7205,
  [SMALL_STATE(275)] = 7220,
  [SMALL_STATE(276)] = 7235,
  [SMALL_STATE(277)] = 7250,
  [SMALL_STATE(278)] = 7265,
  [SMALL_STATE(279)] = 7280,
  [SMALL_STATE(280)] = 7297,
  [SMALL_STATE(281)] = 7307,
  [SMALL_STATE(282)] = 7317,
  [SMALL_STATE(283)] = 7327,
  [SMALL_STATE(284)] = 7337,
  [SMALL_STATE(285)] = 7347,
  [SMALL_STATE(286)] = 7357,
  [SMALL_STATE(287)] = 7367,
  [SMALL_STATE(288)] = 7377,
  [SMALL_STATE(289)] = 7391,
  [SMALL_STATE(290)] = 7405,
  [SMALL_STATE(291)] = 7417,
  [SMALL_STATE(292)] = 7427,
  [SMALL_STATE(293)] = 7437,
  [SMALL_STATE(294)] = 7447,
  [SMALL_STATE(295)] = 7459,
  [SMALL_STATE(296)] = 7473,
  [SMALL_STATE(297)] = 7483,
  [SMALL_STATE(298)] = 7497,
  [SMALL_STATE(299)] = 7507,
  [SMALL_STATE(300)] = 7517,
  [SMALL_STATE(301)] = 7529,
  [SMALL_STATE(302)] = 7538,
  [SMALL_STATE(303)] = 7549,
  [SMALL_STATE(304)] = 7560,
  [SMALL_STATE(305)] = 7571,
  [SMALL_STATE(306)] = 7582,
  [SMALL_STATE(307)] = 7593,
  [SMALL_STATE(308)] = 7604,
  [SMALL_STATE(309)] = 7615,
  [SMALL_STATE(310)] = 7624,
  [SMALL_STATE(311)] = 7633,
  [SMALL_STATE(312)] = 7644,
  [SMALL_STATE(313)] = 7655,
  [SMALL_STATE(314)] = 7664,
  [SMALL_STATE(315)] = 7675,
  [SMALL_STATE(316)] = 7686,
  [SMALL_STATE(317)] = 7695,
  [SMALL_STATE(318)] = 7706,
  [SMALL_STATE(319)] = 7717,
  [SMALL_STATE(320)] = 7728,
  [SMALL_STATE(321)] = 7739,
  [SMALL_STATE(322)] = 7748,
  [SMALL_STATE(323)] = 7759,
  [SMALL_STATE(324)] = 7768,
  [SMALL_STATE(325)] = 7779,
  [SMALL_STATE(326)] = 7790,
  [SMALL_STATE(327)] = 7798,
  [SMALL_STATE(328)] = 7806,
  [SMALL_STATE(329)] = 7814,
  [SMALL_STATE(330)] = 7822,
  [SMALL_STATE(331)] = 7830,
  [SMALL_STATE(332)] = 7838,
  [SMALL_STATE(333)] = 7846,
  [SMALL_STATE(334)] = 7854,
  [SMALL_STATE(335)] = 7862,
  [SMALL_STATE(336)] = 7870,
  [SMALL_STATE(337)] = 7878,
  [SMALL_STATE(338)] = 7886,
  [SMALL_STATE(339)] = 7894,
  [SMALL_STATE(340)] = 7902,
  [SMALL_STATE(341)] = 7910,
  [SMALL_STATE(342)] = 7918,
  [SMALL_STATE(343)] = 7926,
  [SMALL_STATE(344)] = 7934,
  [SMALL_STATE(345)] = 7942,
  [SMALL_STATE(346)] = 7950,
  [SMALL_STATE(347)] = 7958,
  [SMALL_STATE(348)] = 7966,
  [SMALL_STATE(349)] = 7974,
  [SMALL_STATE(350)] = 7982,
  [SMALL_STATE(351)] = 7990,
  [SMALL_STATE(352)] = 7998,
  [SMALL_STATE(353)] = 8006,
  [SMALL_STATE(354)] = 8014,
  [SMALL_STATE(355)] = 8022,
  [SMALL_STATE(356)] = 8030,
  [SMALL_STATE(357)] = 8038,
  [SMALL_STATE(358)] = 8046,
  [SMALL_STATE(359)] = 8054,
  [SMALL_STATE(360)] = 8062,
  [SMALL_STATE(361)] = 8070,
  [SMALL_STATE(362)] = 8078,
  [SMALL_STATE(363)] = 8086,
  [SMALL_STATE(364)] = 8094,
  [SMALL_STATE(365)] = 8102,
  [SMALL_STATE(366)] = 8110,
  [SMALL_STATE(367)] = 8118,
  [SMALL_STATE(368)] = 8126,
  [SMALL_STATE(369)] = 8134,
  [SMALL_STATE(370)] = 8142,
  [SMALL_STATE(371)] = 8150,
  [SMALL_STATE(372)] = 8158,
  [SMALL_STATE(373)] = 8166,
  [SMALL_STATE(374)] = 8174,
  [SMALL_STATE(375)] = 8182,
  [SMALL_STATE(376)] = 8190,
  [SMALL_STATE(377)] = 8198,
  [SMALL_STATE(378)] = 8206,
  [SMALL_STATE(379)] = 8214,
  [SMALL_STATE(380)] = 8222,
  [SMALL_STATE(381)] = 8230,
  [SMALL_STATE(382)] = 8238,
  [SMALL_STATE(383)] = 8246,
  [SMALL_STATE(384)] = 8254,
  [SMALL_STATE(385)] = 8262,
  [SMALL_STATE(386)] = 8270,
  [SMALL_STATE(387)] = 8278,
  [SMALL_STATE(388)] = 8286,
  [SMALL_STATE(389)] = 8294,
  [SMALL_STATE(390)] = 8302,
  [SMALL_STATE(391)] = 8310,
  [SMALL_STATE(392)] = 8318,
  [SMALL_STATE(393)] = 8326,
  [SMALL_STATE(394)] = 8334,
  [SMALL_STATE(395)] = 8342,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [33] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_document, 1, 0, 0),
  [35] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0),
  [37] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(230),
  [40] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(177),
  [43] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(196),
  [46] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(362),
  [49] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(378),
  [52] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(332),
  [55] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(339),
  [58] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(388),
  [61] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(341),
  [64] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(234),
  [67] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(338),
  [70] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(345),
  [73] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(314),
  [76] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2, 0, 0), SHIFT_REPEAT(360),
  [79] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_extension, 3, 0, 0),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [85] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_extension, 3, 0, 0),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [89] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_extension, 3, 0, 0),
  [91] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_extension, 3, 0, 0),
  [93] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_definition, 3, 0, 0),
  [95] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_definition, 3, 0, 0),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_definition, 3, 0, 0),
  [99] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_definition, 3, 0, 0),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(67),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_definition, 2, 0, 0),
  [113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_definition, 2, 0, 0),
  [115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_definition, 2, 0, 0),
  [117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_definition, 2, 0, 0),
  [119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type_definition, 2, 0, 0),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type_definition, 2, 0, 0),
  [125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_object_type_extension, 3, 0, 0),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_object_type_extension, 3, 0, 0),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type_extension, 3, 0, 0),
  [135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type_extension, 3, 0, 0),
  [137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type_definition, 3, 0, 0),
  [139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type_definition, 3, 0, 0),
  [141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_type, 1, 0, 0),
  [143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_named_type, 1, 0, 0),
  [145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_extension, 4, 0, 0),
  [147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_extension, 4, 0, 0),
  [149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_definition, 4, 0, 0),
  [151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_definition, 4, 0, 0),
  [153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_extension, 4, 0, 0),
  [155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_extension, 4, 0, 0),
  [157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_definition, 4, 0, 0),
  [159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_definition, 4, 0, 0),
  [161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type_definition, 3, 0, 0),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type_definition, 3, 0, 0),
  [167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_object_type_definition, 3, 0, 0),
  [169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_object_type_definition, 3, 0, 0),
  [171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type_definition, 2, 0, 0),
  [173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type_definition, 2, 0, 0),
  [175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type_extension, 3, 0, 0),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type_extension, 3, 0, 0),
  [179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_object_type_definition, 2, 0, 0),
  [181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_object_type_definition, 2, 0, 0),
  [183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scalar_type_definition, 3, 0, 0),
  [185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scalar_type_definition, 3, 0, 0),
  [187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scalar_type_definition, 2, 0, 0),
  [189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scalar_type_definition, 2, 0, 0),
  [191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 2, 0, 0),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 2, 0, 0),
  [197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directives, 1, 0, 0),
  [199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directives, 1, 0, 0),
  [201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_directives_repeat1, 2, 0, 0),
  [203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_directives_repeat1, 2, 0, 0),
  [205] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_directives_repeat1, 2, 0, 0), SHIFT_REPEAT(361),
  [208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(274),
  [235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(367),
  [238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(390),
  [241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(391),
  [244] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [250] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(141),
  [253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(41),
  [256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0),
  [258] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_list_value_repeat1, 2, 0, 0), SHIFT_REPEAT(138),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_input_object_type_extension_repeat1, 2, 0, 0),
  [269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_input_object_type_extension_repeat1, 2, 0, 0), SHIFT_REPEAT(191),
  [272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_input_object_type_extension_repeat1, 2, 0, 0),
  [274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 3, 0, 0),
  [276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 3, 0, 0),
  [278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type_extension, 4, 0, 0),
  [280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type_extension, 4, 0, 0),
  [282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_object_type_extension, 4, 0, 0),
  [284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_object_type_extension, 4, 0, 0),
  [286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_interfaces, 2, 0, 0),
  [288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_implements_interfaces, 2, 0, 0),
  [290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type_definition, 4, 0, 0),
  [292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type_definition, 4, 0, 0),
  [294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_object_type_extension, 5, 0, 0),
  [296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_object_type_extension, 5, 0, 0),
  [298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_interfaces, 3, 0, 0),
  [300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_implements_interfaces, 3, 0, 0),
  [302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0),
  [306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type_definition, 4, 0, 0),
  [310] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type_definition, 4, 0, 0),
  [312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_object_type_definition, 4, 0, 0),
  [314] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_object_type_definition, 4, 0, 0),
  [316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_extension, 5, 0, 0),
  [336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_extension, 5, 0, 0),
  [338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_extension, 5, 0, 0),
  [340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_extension, 5, 0, 0),
  [342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type_extension, 5, 0, 0),
  [344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type_extension, 5, 0, 0),
  [346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type_extension, 4, 0, 0),
  [348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type_extension, 4, 0, 0),
  [350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_member_types, 3, 0, 0),
  [352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_member_types, 3, 0, 0),
  [354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_executable_directive_location, 1, 0, 0),
  [356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_executable_directive_location, 1, 0, 0),
  [358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_system_directive_location, 1, 0, 0),
  [360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_system_directive_location, 1, 0, 0),
  [362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive_definition, 5, 0, 0),
  [364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [366] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive_definition, 5, 0, 0),
  [368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive_locations, 1, 0, 0),
  [370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive_locations, 1, 0, 0),
  [372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_definition, 5, 0, 0),
  [374] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_definition, 5, 0, 0),
  [376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_definition, 5, 0, 0),
  [378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_definition, 5, 0, 0),
  [380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type_definition, 5, 0, 0),
  [382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type_definition, 5, 0, 0),
  [384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive_locations, 2, 0, 0),
  [386] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive_locations, 2, 0, 0),
  [388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive_definition, 6, 0, 0),
  [390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive_definition, 6, 0, 0),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(249),
  [402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive_locations, 3, 0, 0),
  [412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive_locations, 3, 0, 0),
  [414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive_definition, 7, 0, 0),
  [416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive_definition, 7, 0, 0),
  [418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive_definition, 8, 0, 0),
  [420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive_definition, 8, 0, 0),
  [422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_member_types, 2, 0, 0),
  [424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_member_types, 2, 0, 0),
  [426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive_location, 1, 0, 0),
  [428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive_location, 1, 0, 0),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_extension, 1, 0, 0),
  [432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_extension, 1, 0, 0),
  [434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fields_definition, 3, 0, 0),
  [436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fields_definition, 3, 0, 0),
  [438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_system_definition, 1, 0, 0),
  [440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_system_definition, 1, 0, 0),
  [442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_values_definition, 3, 0, 0),
  [444] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_values_definition, 3, 0, 0),
  [446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_fields_definition, 3, 0, 0),
  [448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_fields_definition, 3, 0, 0),
  [450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fragment_definition, 5, 0, 0),
  [452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fragment_definition, 5, 0, 0),
  [454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_executable_definition, 1, 0, 0),
  [456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_executable_definition, 1, 0, 0),
  [458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_definition, 1, 0, 0),
  [460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_definition, 1, 0, 0),
  [462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operation_definition, 5, 0, 0),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operation_definition, 5, 0, 0),
  [466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fragment_definition, 4, 0, 0),
  [468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fragment_definition, 4, 0, 0),
  [470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type_definition, 5, 0, 0),
  [472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type_definition, 5, 0, 0),
  [474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_object_type_definition, 5, 0, 0),
  [476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_object_type_definition, 5, 0, 0),
  [478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operation_definition, 4, 0, 0),
  [480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operation_definition, 4, 0, 0),
  [482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_extension, 6, 0, 0),
  [484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_schema_extension, 6, 0, 0),
  [486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_extension, 6, 0, 0),
  [488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_extension, 6, 0, 0),
  [490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_extension, 6, 0, 0),
  [492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_extension, 6, 0, 0),
  [494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scalar_type_definition, 4, 0, 0),
  [496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scalar_type_definition, 4, 0, 0),
  [498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operation_definition, 2, 0, 0),
  [500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operation_definition, 2, 0, 0),
  [502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_definition, 6, 0, 0),
  [504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_schema_definition, 6, 0, 0),
  [506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type_definition, 6, 0, 0),
  [508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type_definition, 6, 0, 0),
  [510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type_definition, 6, 0, 0),
  [512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type_definition, 6, 0, 0),
  [514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_definition, 4, 0, 0),
  [516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_schema_definition, 4, 0, 0),
  [518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_definition, 5, 0, 0),
  [520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_schema_definition, 5, 0, 0),
  [522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_selection_set, 3, 0, 0),
  [524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_selection_set, 3, 0, 0),
  [526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_extension, 5, 0, 0),
  [528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_schema_extension, 5, 0, 0),
  [530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scalar_type_extension, 4, 0, 0),
  [532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scalar_type_extension, 4, 0, 0),
  [534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type_extension, 5, 0, 0),
  [536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type_extension, 5, 0, 0),
  [538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operation_definition, 3, 0, 0),
  [540] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operation_definition, 3, 0, 0),
  [542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 1, 0, 0),
  [544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 1, 0, 0),
  [546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operation_definition, 1, 0, 0),
  [548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operation_definition, 1, 0, 0),
  [550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_system_extension, 1, 0, 0),
  [552] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_system_extension, 1, 0, 0),
  [554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_value, 1, 0, 0),
  [556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_value, 1, 0, 0),
  [558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_value, 2, 0, 0),
  [560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_value, 2, 0, 0),
  [562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 1, 0, 0),
  [564] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 1, 0, 0),
  [566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_value, 1, 0, 0),
  [568] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_value, 1, 0, 0),
  [570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_value, 2, 0, 0),
  [572] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_value, 2, 0, 0),
  [574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_value, 3, 0, 0),
  [576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_value, 3, 0, 0),
  [578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_value, 3, 0, 0),
  [580] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_value, 3, 0, 0),
  [582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable, 2, 0, 0),
  [584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable, 2, 0, 0),
  [586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_value, 3, 0, 0),
  [588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_value, 3, 0, 0),
  [590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_value_definition, 4, 0, 0),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [594] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_value_definition, 4, 0, 0),
  [596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_value_definition, 3, 0, 0),
  [600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_value_definition, 3, 0, 0),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(265),
  [608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 1, 0, 0),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_value_definition, 5, 0, 0),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_value_definition, 5, 0, 0),
  [618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 0),
  [632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_input_fields_definition_repeat1, 2, 0, 0),
  [636] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_input_fields_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(386),
  [639] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_input_fields_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(387),
  [642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_input_fields_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(346),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_type, 3, 0, 0),
  [647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_type, 3, 0, 0),
  [649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_directives_repeat1, 2, 0, 0), SHIFT_REPEAT(350),
  [652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 2, 0, 0),
  [654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_selection_set_repeat1, 2, 0, 0),
  [658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_selection_set_repeat1, 2, 0, 0), SHIFT_REPEAT(149),
  [661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_selection_set_repeat1, 2, 0, 0), SHIFT_REPEAT(151),
  [664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_values_definition_repeat1, 2, 0, 0),
  [666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_values_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(386),
  [669] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_values_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(387),
  [672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_values_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(223),
  [675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_value_definition, 1, 0, 0),
  [685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_value_definition, 1, 0, 0),
  [687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_description, 1, 0, 0),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fields_definition_repeat1, 2, 0, 0),
  [709] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fields_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(386),
  [712] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fields_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(387),
  [715] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fields_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(297),
  [718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_value_definition, 2, 0, 0),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_value_definition, 2, 0, 0),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_definition, 3, 0, 0),
  [724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_definition, 3, 0, 0),
  [732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_definition, 3, 0, 0),
  [734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_definition, 4, 0, 0),
  [736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_definition, 4, 0, 0),
  [738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_definition, 5, 0, 0),
  [740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_definition, 5, 0, 0),
  [742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_non_null_type, 2, 0, 0),
  [744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_non_null_type, 2, 0, 0),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fragment_spread, 2, 0, 0),
  [752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 3, 0, 0),
  [756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_schema_definition_repeat1, 2, 0, 0),
  [776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_schema_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(234),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_definition, 4, 0, 0),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_value, 2, 0, 0),
  [795] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_value, 2, 0, 0),
  [797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 4, 0, 0),
  [801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_definitions_repeat1, 2, 0, 0),
  [805] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(333),
  [808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operation_type, 1, 0, 0),
  [810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_value_definition, 6, 0, 0),
  [812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_value_definition, 6, 0, 0),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [816] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_directives_repeat1, 2, 0, 0), SHIFT_REPEAT(374),
  [819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_root_operation_type_definition, 3, 0, 0),
  [827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0),
  [829] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(363),
  [832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_value_repeat1, 2, 0, 0),
  [834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_value_repeat1, 2, 0, 0), SHIFT_REPEAT(330),
  [837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_definition, 6, 0, 0),
  [843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_definition, 6, 0, 0),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fragment_name, 1, 0, 0),
  [853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_value_definition, 3, 0, 0),
  [855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_value_definition, 3, 0, 0),
  [857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_definition, 3, 0, 0),
  [881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fragment_spread, 3, 0, 0),
  [883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_fragment, 3, 0, 0),
  [885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_selection, 1, 0, 0),
  [887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_fragment, 4, 0, 0),
  [889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_fragment, 2, 0, 0),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 5, 0, 0),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_definitions, 3, 0, 0),
  [903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_condition, 2, 0, 0),
  [905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 3, 0, 0),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_definition, 6, 0, 0),
  [913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_field, 3, 0, 0),
  [915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_definition, 5, 0, 0),
  [919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_field, 4, 0, 0),
  [921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias, 2, 0, 0),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [943] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [999] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [1007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [1017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [1019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [1031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [1035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [1039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [1041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(384),
  [1043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_graphql(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "graphql",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 1,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
